# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="replace_text_online_request.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import json

from six.moves.urllib.parse import quote
from asposewordscloud import *
from asposewordscloud.models import *
from asposewordscloud.models.requests import *
from asposewordscloud.models.responses import *

class ReplaceTextOnlineRequest(BaseRequestObject):
    """
    Request model for replace_text_online operation.
    Initializes a new instance.
    :param document The document.
    :param replace_text The replace operation settings.
    :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
    :param password Password of protected Word document. Use the parameter to pass a password via SDK. SDK encrypts it automatically. We don't recommend to use the parameter to pass a plain password for direct call of API.
    :param encrypted_password Password of protected Word document. Use the parameter to pass an encrypted password for direct calls of API. See SDK code for encyption details.
    :param dest_file_name Result path of the document after the operation. If this parameter is omitted then result of the operation will be saved as the source document.
    :param revision_author Initials of the author to use for revisions.If you set this parameter and then make some changes to the document programmatically, save the document and later open the document in MS Word you will see these changes as revisions.
    :param revision_date_time The date and time to use for revisions.
    """

    def __init__(self, document, replace_text, load_encoding=None, password=None, encrypted_password=None, dest_file_name=None, revision_author=None, revision_date_time=None):
        self.document = document
        self.replace_text = replace_text
        self.load_encoding = load_encoding
        self.password = password
        self.encrypted_password = encrypted_password
        self.dest_file_name = dest_file_name
        self.revision_author = revision_author
        self.revision_date_time = revision_date_time

    def create_http_request(self, api_client):
        # verify the required parameter 'document' is set
        if self.document is None:
            raise ValueError("Missing the required parameter `document` when calling `replace_text_online`")  # noqa: E501
        # verify the required parameter 'replace_text' is set
        if self.replace_text is None:
            raise ValueError("Missing the required parameter `replace_text` when calling `replace_text_online`")  # noqa: E501

        path = '/v4.0/words/online/put/replaceText'
        path_params = {}

        # path parameters
        collection_formats = {}
        if path_params:
            path_params = api_client.sanitize_for_serialization(path_params)
            path_params = api_client.parameters_to_tuples(path_params, collection_formats)
            for k, v in path_params:
                # specified safe chars, encode everything
                path = path.replace(
                    '{%s}' % k,
                    quote(str(v), safe=api_client.configuration.safe_chars_for_path_param)
                )

        # remove optional path parameters
        path = path.replace('//', '/')

        query_params = []
        if self.load_encoding is not None:
                query_params.append(('loadEncoding', self.load_encoding))  # noqa: E501
        if self.password is not None:
                query_params.append(('password', self.password))  # noqa: E501
        if self.encrypted_password is not None:
                query_params.append(('encryptedPassword', self.encrypted_password))  # noqa: E501
        if self.dest_file_name is not None:
                query_params.append(('destFileName', self.dest_file_name))  # noqa: E501
        if self.revision_author is not None:
                query_params.append(('revisionAuthor', self.revision_author))  # noqa: E501
        if self.revision_date_time is not None:
                query_params.append(('revisionDateTime', self.revision_date_time))  # noqa: E501

        header_params = {}
        # HTTP header `Content-Type`
        header_params['Content-Type'] = api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        file_content_params = []
        form_params = []
        if self.document is not None:
            form_params.append(['document', self.document, 'file'])  # noqa: E501
        if self.replace_text is not None:
            form_params.append(['replaceText', self.replace_text, 'json'])  # noqa: E501

        for file_content_value in file_content_params:
            form_params.append([file_content_value.reference, file_content_value.content, 'file'])  # noqa: E501

        return {
            "method": "PUT",
            "path": path,
            "body": None,
            "query_params": query_params,
            "header_params": header_params,
            "form_params": form_params,
            "collection_formats": collection_formats,
            "response_type": 'ReplaceTextOnlineResponse'  # noqa: E501
        }

    def get_response_type(self):
        return 'ReplaceTextOnlineResponse'  # noqa: E501

    def deserialize_response(self, api_client, response):
        multipart = self.getparts(response)
        return ReplaceTextOnlineResponse(
          api_client.deserialize(api_client.findMultipartByName(multipart, "Model").content, api_client.findMultipartByName(multipart, "Model").headers, ReplaceTextResponse),
          api_client.deserialize_files_collection(api_client.findMultipartByName(multipart, "Document").content, api_client.findMultipartByName(multipart, "Document").headers))



# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="page_setup.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class PageSetup(object):
    """Represents the page setup properties of a section. PageSetup object contains all the page setup attributes of a section (left margin, bottom margin, paper size, and so on) as properties.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'bidi': 'bool',
        'border_always_in_front': 'bool',
        'border_applies_to': 'str',
        'border_distance_from': 'str',
        'bottom_margin': 'float',
        'different_first_page_header_footer': 'bool',
        'first_page_tray': 'int',
        'footer_distance': 'float',
        'gutter': 'float',
        'header_distance': 'float',
        'left_margin': 'float',
        'line_number_count_by': 'int',
        'line_number_distance_from_text': 'float',
        'line_number_restart_mode': 'str',
        'line_starting_number': 'int',
        'orientation': 'str',
        'other_pages_tray': 'int',
        'page_height': 'float',
        'page_number_style': 'str',
        'page_starting_number': 'int',
        'page_width': 'float',
        'paper_size': 'str',
        'restart_page_numbering': 'bool',
        'right_margin': 'float',
        'rtl_gutter': 'bool',
        'section_start': 'str',
        'suppress_endnotes': 'bool',
        'top_margin': 'float',
        'vertical_alignment': 'str'
    }

    attribute_map = {
        'link': 'Link',
        'bidi': 'Bidi',
        'border_always_in_front': 'BorderAlwaysInFront',
        'border_applies_to': 'BorderAppliesTo',
        'border_distance_from': 'BorderDistanceFrom',
        'bottom_margin': 'BottomMargin',
        'different_first_page_header_footer': 'DifferentFirstPageHeaderFooter',
        'first_page_tray': 'FirstPageTray',
        'footer_distance': 'FooterDistance',
        'gutter': 'Gutter',
        'header_distance': 'HeaderDistance',
        'left_margin': 'LeftMargin',
        'line_number_count_by': 'LineNumberCountBy',
        'line_number_distance_from_text': 'LineNumberDistanceFromText',
        'line_number_restart_mode': 'LineNumberRestartMode',
        'line_starting_number': 'LineStartingNumber',
        'orientation': 'Orientation',
        'other_pages_tray': 'OtherPagesTray',
        'page_height': 'PageHeight',
        'page_number_style': 'PageNumberStyle',
        'page_starting_number': 'PageStartingNumber',
        'page_width': 'PageWidth',
        'paper_size': 'PaperSize',
        'restart_page_numbering': 'RestartPageNumbering',
        'right_margin': 'RightMargin',
        'rtl_gutter': 'RtlGutter',
        'section_start': 'SectionStart',
        'suppress_endnotes': 'SuppressEndnotes',
        'top_margin': 'TopMargin',
        'vertical_alignment': 'VerticalAlignment'
    }

    def __init__(self, link=None, bidi=None, border_always_in_front=None, border_applies_to=None, border_distance_from=None, bottom_margin=None, different_first_page_header_footer=None, first_page_tray=None, footer_distance=None, gutter=None, header_distance=None, left_margin=None, line_number_count_by=None, line_number_distance_from_text=None, line_number_restart_mode=None, line_starting_number=None, orientation=None, other_pages_tray=None, page_height=None, page_number_style=None, page_starting_number=None, page_width=None, paper_size=None, restart_page_numbering=None, right_margin=None, rtl_gutter=None, section_start=None, suppress_endnotes=None, top_margin=None, vertical_alignment=None):  # noqa: E501
        """PageSetup - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._bidi = None
        self._border_always_in_front = None
        self._border_applies_to = None
        self._border_distance_from = None
        self._bottom_margin = None
        self._different_first_page_header_footer = None
        self._first_page_tray = None
        self._footer_distance = None
        self._gutter = None
        self._header_distance = None
        self._left_margin = None
        self._line_number_count_by = None
        self._line_number_distance_from_text = None
        self._line_number_restart_mode = None
        self._line_starting_number = None
        self._orientation = None
        self._other_pages_tray = None
        self._page_height = None
        self._page_number_style = None
        self._page_starting_number = None
        self._page_width = None
        self._paper_size = None
        self._restart_page_numbering = None
        self._right_margin = None
        self._rtl_gutter = None
        self._section_start = None
        self._suppress_endnotes = None
        self._top_margin = None
        self._vertical_alignment = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if bidi is not None:
            self.bidi = bidi
        if border_always_in_front is not None:
            self.border_always_in_front = border_always_in_front
        if border_applies_to is not None:
            self.border_applies_to = border_applies_to
        if border_distance_from is not None:
            self.border_distance_from = border_distance_from
        if bottom_margin is not None:
            self.bottom_margin = bottom_margin
        if different_first_page_header_footer is not None:
            self.different_first_page_header_footer = different_first_page_header_footer
        if first_page_tray is not None:
            self.first_page_tray = first_page_tray
        if footer_distance is not None:
            self.footer_distance = footer_distance
        if gutter is not None:
            self.gutter = gutter
        if header_distance is not None:
            self.header_distance = header_distance
        if left_margin is not None:
            self.left_margin = left_margin
        if line_number_count_by is not None:
            self.line_number_count_by = line_number_count_by
        if line_number_distance_from_text is not None:
            self.line_number_distance_from_text = line_number_distance_from_text
        if line_number_restart_mode is not None:
            self.line_number_restart_mode = line_number_restart_mode
        if line_starting_number is not None:
            self.line_starting_number = line_starting_number
        if orientation is not None:
            self.orientation = orientation
        if other_pages_tray is not None:
            self.other_pages_tray = other_pages_tray
        if page_height is not None:
            self.page_height = page_height
        if page_number_style is not None:
            self.page_number_style = page_number_style
        if page_starting_number is not None:
            self.page_starting_number = page_starting_number
        if page_width is not None:
            self.page_width = page_width
        if paper_size is not None:
            self.paper_size = paper_size
        if restart_page_numbering is not None:
            self.restart_page_numbering = restart_page_numbering
        if right_margin is not None:
            self.right_margin = right_margin
        if rtl_gutter is not None:
            self.rtl_gutter = rtl_gutter
        if section_start is not None:
            self.section_start = section_start
        if suppress_endnotes is not None:
            self.suppress_endnotes = suppress_endnotes
        if top_margin is not None:
            self.top_margin = top_margin
        if vertical_alignment is not None:
            self.vertical_alignment = vertical_alignment

    @property
    def link(self):
        """Gets the link of this PageSetup.  # noqa: E501

        Gets or sets the link to the document.  # noqa: E501

        :return: The link of this PageSetup.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this PageSetup.

        Gets or sets the link to the document.  # noqa: E501

        :param link: The link of this PageSetup.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def bidi(self):
        """Gets the bidi of this PageSetup.  # noqa: E501

        Gets or sets a value indicating whether this section contains bidirectional (complex scripts) text. When true, the columns in this section are laid out from right to left.  # noqa: E501

        :return: The bidi of this PageSetup.  # noqa: E501
        :rtype: bool
        """
        return self._bidi

    @bidi.setter
    def bidi(self, bidi):
        """Sets the bidi of this PageSetup.

        Gets or sets a value indicating whether this section contains bidirectional (complex scripts) text. When true, the columns in this section are laid out from right to left.  # noqa: E501

        :param bidi: The bidi of this PageSetup.  # noqa: E501
        :type: bool
        """
        self._bidi = bidi

    @property
    def border_always_in_front(self):
        """Gets the border_always_in_front of this PageSetup.  # noqa: E501

        Gets or sets a value indicating whether the page border is positioned relative to intersecting texts and objects.  # noqa: E501

        :return: The border_always_in_front of this PageSetup.  # noqa: E501
        :rtype: bool
        """
        return self._border_always_in_front

    @border_always_in_front.setter
    def border_always_in_front(self, border_always_in_front):
        """Sets the border_always_in_front of this PageSetup.

        Gets or sets a value indicating whether the page border is positioned relative to intersecting texts and objects.  # noqa: E501

        :param border_always_in_front: The border_always_in_front of this PageSetup.  # noqa: E501
        :type: bool
        """
        self._border_always_in_front = border_always_in_front

    @property
    def border_applies_to(self):
        """Gets the border_applies_to of this PageSetup.  # noqa: E501

        Gets or sets the option that controls which pages the page border is printed on.  # noqa: E501

        :return: The border_applies_to of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._border_applies_to

    @border_applies_to.setter
    def border_applies_to(self, border_applies_to):
        """Sets the border_applies_to of this PageSetup.

        Gets or sets the option that controls which pages the page border is printed on.  # noqa: E501

        :param border_applies_to: The border_applies_to of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["AllPages", "FirstPage", "OtherPages"]  # noqa: E501
        if not border_applies_to.isdigit():
            if border_applies_to not in allowed_values:
                raise ValueError(
                    "Invalid value for `border_applies_to` ({0}), must be one of {1}"  # noqa: E501
                    .format(border_applies_to, allowed_values))
            self._border_applies_to = border_applies_to
        else:
            self._border_applies_to = allowed_values[int(border_applies_to) if six.PY3 else long(border_applies_to)]

    @property
    def border_distance_from(self):
        """Gets the border_distance_from of this PageSetup.  # noqa: E501

        Gets or sets the value, that indicates whether the specified page border is measured from the edge of the page or from the text it surrounds.  # noqa: E501

        :return: The border_distance_from of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._border_distance_from

    @border_distance_from.setter
    def border_distance_from(self, border_distance_from):
        """Sets the border_distance_from of this PageSetup.

        Gets or sets the value, that indicates whether the specified page border is measured from the edge of the page or from the text it surrounds.  # noqa: E501

        :param border_distance_from: The border_distance_from of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["Text", "PageEdge"]  # noqa: E501
        if not border_distance_from.isdigit():
            if border_distance_from not in allowed_values:
                raise ValueError(
                    "Invalid value for `border_distance_from` ({0}), must be one of {1}"  # noqa: E501
                    .format(border_distance_from, allowed_values))
            self._border_distance_from = border_distance_from
        else:
            self._border_distance_from = allowed_values[int(border_distance_from) if six.PY3 else long(border_distance_from)]

    @property
    def bottom_margin(self):
        """Gets the bottom_margin of this PageSetup.  # noqa: E501

        Gets or sets the distance (in points) between the bottom edge of the page and the bottom boundary of the body text.  # noqa: E501

        :return: The bottom_margin of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._bottom_margin

    @bottom_margin.setter
    def bottom_margin(self, bottom_margin):
        """Sets the bottom_margin of this PageSetup.

        Gets or sets the distance (in points) between the bottom edge of the page and the bottom boundary of the body text.  # noqa: E501

        :param bottom_margin: The bottom_margin of this PageSetup.  # noqa: E501
        :type: float
        """
        self._bottom_margin = bottom_margin

    @property
    def different_first_page_header_footer(self):
        """Gets the different_first_page_header_footer of this PageSetup.  # noqa: E501

        Gets or sets a value indicating whether a different header or footer is used on the first page.  # noqa: E501

        :return: The different_first_page_header_footer of this PageSetup.  # noqa: E501
        :rtype: bool
        """
        return self._different_first_page_header_footer

    @different_first_page_header_footer.setter
    def different_first_page_header_footer(self, different_first_page_header_footer):
        """Sets the different_first_page_header_footer of this PageSetup.

        Gets or sets a value indicating whether a different header or footer is used on the first page.  # noqa: E501

        :param different_first_page_header_footer: The different_first_page_header_footer of this PageSetup.  # noqa: E501
        :type: bool
        """
        self._different_first_page_header_footer = different_first_page_header_footer

    @property
    def first_page_tray(self):
        """Gets the first_page_tray of this PageSetup.  # noqa: E501

        Gets or sets the paper tray (bin) to use for the first page of a section. The value is implementation (printer) specific.  # noqa: E501

        :return: The first_page_tray of this PageSetup.  # noqa: E501
        :rtype: int
        """
        return self._first_page_tray

    @first_page_tray.setter
    def first_page_tray(self, first_page_tray):
        """Sets the first_page_tray of this PageSetup.

        Gets or sets the paper tray (bin) to use for the first page of a section. The value is implementation (printer) specific.  # noqa: E501

        :param first_page_tray: The first_page_tray of this PageSetup.  # noqa: E501
        :type: int
        """
        self._first_page_tray = first_page_tray

    @property
    def footer_distance(self):
        """Gets the footer_distance of this PageSetup.  # noqa: E501

        Gets or sets the distance (in points) between the footer and the bottom of the page.  # noqa: E501

        :return: The footer_distance of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._footer_distance

    @footer_distance.setter
    def footer_distance(self, footer_distance):
        """Sets the footer_distance of this PageSetup.

        Gets or sets the distance (in points) between the footer and the bottom of the page.  # noqa: E501

        :param footer_distance: The footer_distance of this PageSetup.  # noqa: E501
        :type: float
        """
        self._footer_distance = footer_distance

    @property
    def gutter(self):
        """Gets the gutter of this PageSetup.  # noqa: E501

        Gets or sets the amount of extra space added to the margin for document binding.  # noqa: E501

        :return: The gutter of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._gutter

    @gutter.setter
    def gutter(self, gutter):
        """Sets the gutter of this PageSetup.

        Gets or sets the amount of extra space added to the margin for document binding.  # noqa: E501

        :param gutter: The gutter of this PageSetup.  # noqa: E501
        :type: float
        """
        self._gutter = gutter

    @property
    def header_distance(self):
        """Gets the header_distance of this PageSetup.  # noqa: E501

        Gets or sets the distance (in points) between the header and the top of the page.  # noqa: E501

        :return: The header_distance of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._header_distance

    @header_distance.setter
    def header_distance(self, header_distance):
        """Sets the header_distance of this PageSetup.

        Gets or sets the distance (in points) between the header and the top of the page.  # noqa: E501

        :param header_distance: The header_distance of this PageSetup.  # noqa: E501
        :type: float
        """
        self._header_distance = header_distance

    @property
    def left_margin(self):
        """Gets the left_margin of this PageSetup.  # noqa: E501

        Gets or sets the distance (in points) between the left edge of the page and the left boundary of the body text.  # noqa: E501

        :return: The left_margin of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._left_margin

    @left_margin.setter
    def left_margin(self, left_margin):
        """Sets the left_margin of this PageSetup.

        Gets or sets the distance (in points) between the left edge of the page and the left boundary of the body text.  # noqa: E501

        :param left_margin: The left_margin of this PageSetup.  # noqa: E501
        :type: float
        """
        self._left_margin = left_margin

    @property
    def line_number_count_by(self):
        """Gets the line_number_count_by of this PageSetup.  # noqa: E501

        Gets or sets the numeric increment for line numbers.  # noqa: E501

        :return: The line_number_count_by of this PageSetup.  # noqa: E501
        :rtype: int
        """
        return self._line_number_count_by

    @line_number_count_by.setter
    def line_number_count_by(self, line_number_count_by):
        """Sets the line_number_count_by of this PageSetup.

        Gets or sets the numeric increment for line numbers.  # noqa: E501

        :param line_number_count_by: The line_number_count_by of this PageSetup.  # noqa: E501
        :type: int
        """
        self._line_number_count_by = line_number_count_by

    @property
    def line_number_distance_from_text(self):
        """Gets the line_number_distance_from_text of this PageSetup.  # noqa: E501

        Gets or sets the distance between the right edge of line numbers and the left edge of the document. Set this property to zero for automatic distance between the line numbers and text of the document.  # noqa: E501

        :return: The line_number_distance_from_text of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._line_number_distance_from_text

    @line_number_distance_from_text.setter
    def line_number_distance_from_text(self, line_number_distance_from_text):
        """Sets the line_number_distance_from_text of this PageSetup.

        Gets or sets the distance between the right edge of line numbers and the left edge of the document. Set this property to zero for automatic distance between the line numbers and text of the document.  # noqa: E501

        :param line_number_distance_from_text: The line_number_distance_from_text of this PageSetup.  # noqa: E501
        :type: float
        """
        self._line_number_distance_from_text = line_number_distance_from_text

    @property
    def line_number_restart_mode(self):
        """Gets the line_number_restart_mode of this PageSetup.  # noqa: E501

        Gets or sets the way line numbering runs  that is, whether it starts over at the beginning of a new page or section or runs continuously.  # noqa: E501

        :return: The line_number_restart_mode of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._line_number_restart_mode

    @line_number_restart_mode.setter
    def line_number_restart_mode(self, line_number_restart_mode):
        """Sets the line_number_restart_mode of this PageSetup.

        Gets or sets the way line numbering runs  that is, whether it starts over at the beginning of a new page or section or runs continuously.  # noqa: E501

        :param line_number_restart_mode: The line_number_restart_mode of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["RestartPage", "RestartSection", "Continuous"]  # noqa: E501
        if not line_number_restart_mode.isdigit():
            if line_number_restart_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `line_number_restart_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(line_number_restart_mode, allowed_values))
            self._line_number_restart_mode = line_number_restart_mode
        else:
            self._line_number_restart_mode = allowed_values[int(line_number_restart_mode) if six.PY3 else long(line_number_restart_mode)]

    @property
    def line_starting_number(self):
        """Gets the line_starting_number of this PageSetup.  # noqa: E501

        Gets or sets the starting line number.  # noqa: E501

        :return: The line_starting_number of this PageSetup.  # noqa: E501
        :rtype: int
        """
        return self._line_starting_number

    @line_starting_number.setter
    def line_starting_number(self, line_starting_number):
        """Sets the line_starting_number of this PageSetup.

        Gets or sets the starting line number.  # noqa: E501

        :param line_starting_number: The line_starting_number of this PageSetup.  # noqa: E501
        :type: int
        """
        self._line_starting_number = line_starting_number

    @property
    def orientation(self):
        """Gets the orientation of this PageSetup.  # noqa: E501

        Gets or sets the orientation of the page. Changing Orientation swaps PageWidth and PageHeight.  # noqa: E501

        :return: The orientation of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._orientation

    @orientation.setter
    def orientation(self, orientation):
        """Sets the orientation of this PageSetup.

        Gets or sets the orientation of the page. Changing Orientation swaps PageWidth and PageHeight.  # noqa: E501

        :param orientation: The orientation of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["Portrait", "Landscape"]  # noqa: E501
        if not orientation.isdigit():
            if orientation not in allowed_values:
                raise ValueError(
                    "Invalid value for `orientation` ({0}), must be one of {1}"  # noqa: E501
                    .format(orientation, allowed_values))
            self._orientation = orientation
        else:
            self._orientation = allowed_values[int(orientation) if six.PY3 else long(orientation)]

    @property
    def other_pages_tray(self):
        """Gets the other_pages_tray of this PageSetup.  # noqa: E501

        Gets or sets the paper tray (bin) to be used for all but the first page of a section. The value is implementation (printer) specific.  # noqa: E501

        :return: The other_pages_tray of this PageSetup.  # noqa: E501
        :rtype: int
        """
        return self._other_pages_tray

    @other_pages_tray.setter
    def other_pages_tray(self, other_pages_tray):
        """Sets the other_pages_tray of this PageSetup.

        Gets or sets the paper tray (bin) to be used for all but the first page of a section. The value is implementation (printer) specific.  # noqa: E501

        :param other_pages_tray: The other_pages_tray of this PageSetup.  # noqa: E501
        :type: int
        """
        self._other_pages_tray = other_pages_tray

    @property
    def page_height(self):
        """Gets the page_height of this PageSetup.  # noqa: E501

        Gets or sets the height of the page in points.  # noqa: E501

        :return: The page_height of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._page_height

    @page_height.setter
    def page_height(self, page_height):
        """Sets the page_height of this PageSetup.

        Gets or sets the height of the page in points.  # noqa: E501

        :param page_height: The page_height of this PageSetup.  # noqa: E501
        :type: float
        """
        self._page_height = page_height

    @property
    def page_number_style(self):
        """Gets the page_number_style of this PageSetup.  # noqa: E501

        Gets or sets the page number format.  # noqa: E501

        :return: The page_number_style of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._page_number_style

    @page_number_style.setter
    def page_number_style(self, page_number_style):
        """Sets the page_number_style of this PageSetup.

        Gets or sets the page number format.  # noqa: E501

        :param page_number_style: The page_number_style of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["Arabic", "UppercaseRoman", "LowercaseRoman", "UppercaseLetter", "LowercaseLetter", "Ordinal", "Number", "OrdinalText", "Hex", "ChicagoManual", "Kanji", "KanjiDigit", "AiueoHalfWidth", "IrohaHalfWidth", "ArabicFullWidth", "ArabicHalfWidth", "KanjiTraditional", "KanjiTraditional2", "NumberInCircle", "DecimalFullWidth", "Aiueo", "Iroha", "LeadingZero", "Bullet", "Ganada", "Chosung", "GB1", "GB2", "GB3", "GB4", "Zodiac1", "Zodiac2", "Zodiac3", "TradChinNum1", "TradChinNum2", "TradChinNum3", "TradChinNum4", "SimpChinNum1", "SimpChinNum2", "SimpChinNum3", "SimpChinNum4", "HanjaRead", "HanjaReadDigit", "Hangul", "Hanja", "Hebrew1", "Arabic1", "Hebrew2", "Arabic2", "HindiLetter1", "HindiLetter2", "HindiArabic", "HindiCardinalText", "ThaiLetter", "ThaiArabic", "ThaiCardinalText", "VietCardinalText", "NumberInDash", "LowercaseRussian", "UppercaseRussian", "None", "Custom"]  # noqa: E501
        if not page_number_style.isdigit():
            if page_number_style not in allowed_values:
                raise ValueError(
                    "Invalid value for `page_number_style` ({0}), must be one of {1}"  # noqa: E501
                    .format(page_number_style, allowed_values))
            self._page_number_style = page_number_style
        else:
            self._page_number_style = allowed_values[int(page_number_style) if six.PY3 else long(page_number_style)]

    @property
    def page_starting_number(self):
        """Gets the page_starting_number of this PageSetup.  # noqa: E501

        Gets or sets the starting page number of the section. The RestartPageNumbering property, if set to false, will override the PageStartingNumber property so that page numbering can continue from the previous section.  # noqa: E501

        :return: The page_starting_number of this PageSetup.  # noqa: E501
        :rtype: int
        """
        return self._page_starting_number

    @page_starting_number.setter
    def page_starting_number(self, page_starting_number):
        """Sets the page_starting_number of this PageSetup.

        Gets or sets the starting page number of the section. The RestartPageNumbering property, if set to false, will override the PageStartingNumber property so that page numbering can continue from the previous section.  # noqa: E501

        :param page_starting_number: The page_starting_number of this PageSetup.  # noqa: E501
        :type: int
        """
        self._page_starting_number = page_starting_number

    @property
    def page_width(self):
        """Gets the page_width of this PageSetup.  # noqa: E501

        Gets or sets the width of the page in points.  # noqa: E501

        :return: The page_width of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._page_width

    @page_width.setter
    def page_width(self, page_width):
        """Sets the page_width of this PageSetup.

        Gets or sets the width of the page in points.  # noqa: E501

        :param page_width: The page_width of this PageSetup.  # noqa: E501
        :type: float
        """
        self._page_width = page_width

    @property
    def paper_size(self):
        """Gets the paper_size of this PageSetup.  # noqa: E501

        Gets or sets the paper size. Setting this property updates PageWidth and PageHeight values. Setting this value to Custom does not change existing values.  # noqa: E501

        :return: The paper_size of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._paper_size

    @paper_size.setter
    def paper_size(self, paper_size):
        """Sets the paper_size of this PageSetup.

        Gets or sets the paper size. Setting this property updates PageWidth and PageHeight values. Setting this value to Custom does not change existing values.  # noqa: E501

        :param paper_size: The paper_size of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["A3", "A4", "A5", "B4", "B5", "Executive", "Folio", "Ledger", "Legal", "Letter", "EnvelopeDL", "Quarto", "Statement", "Tabloid", "Paper10x14", "Paper11x17", "Number10Envelope", "Custom"]  # noqa: E501
        if not paper_size.isdigit():
            if paper_size not in allowed_values:
                raise ValueError(
                    "Invalid value for `paper_size` ({0}), must be one of {1}"  # noqa: E501
                    .format(paper_size, allowed_values))
            self._paper_size = paper_size
        else:
            self._paper_size = allowed_values[int(paper_size) if six.PY3 else long(paper_size)]

    @property
    def restart_page_numbering(self):
        """Gets the restart_page_numbering of this PageSetup.  # noqa: E501

        Gets or sets a value indicating whether page numbering restarts at the beginning of the section. If set to false, the RestartPageNumbering property will override the PageStartingNumber property so that page numbering can continue from the previous section.  # noqa: E501

        :return: The restart_page_numbering of this PageSetup.  # noqa: E501
        :rtype: bool
        """
        return self._restart_page_numbering

    @restart_page_numbering.setter
    def restart_page_numbering(self, restart_page_numbering):
        """Sets the restart_page_numbering of this PageSetup.

        Gets or sets a value indicating whether page numbering restarts at the beginning of the section. If set to false, the RestartPageNumbering property will override the PageStartingNumber property so that page numbering can continue from the previous section.  # noqa: E501

        :param restart_page_numbering: The restart_page_numbering of this PageSetup.  # noqa: E501
        :type: bool
        """
        self._restart_page_numbering = restart_page_numbering

    @property
    def right_margin(self):
        """Gets the right_margin of this PageSetup.  # noqa: E501

        Gets or sets the distance (in points) between the right edge of the page and the right boundary of the body text.  # noqa: E501

        :return: The right_margin of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._right_margin

    @right_margin.setter
    def right_margin(self, right_margin):
        """Sets the right_margin of this PageSetup.

        Gets or sets the distance (in points) between the right edge of the page and the right boundary of the body text.  # noqa: E501

        :param right_margin: The right_margin of this PageSetup.  # noqa: E501
        :type: float
        """
        self._right_margin = right_margin

    @property
    def rtl_gutter(self):
        """Gets the rtl_gutter of this PageSetup.  # noqa: E501

        Gets or sets a value indicating whether Microsoft Word uses gutters for the section based on a right-to-left language or a left-to-right language.  # noqa: E501

        :return: The rtl_gutter of this PageSetup.  # noqa: E501
        :rtype: bool
        """
        return self._rtl_gutter

    @rtl_gutter.setter
    def rtl_gutter(self, rtl_gutter):
        """Sets the rtl_gutter of this PageSetup.

        Gets or sets a value indicating whether Microsoft Word uses gutters for the section based on a right-to-left language or a left-to-right language.  # noqa: E501

        :param rtl_gutter: The rtl_gutter of this PageSetup.  # noqa: E501
        :type: bool
        """
        self._rtl_gutter = rtl_gutter

    @property
    def section_start(self):
        """Gets the section_start of this PageSetup.  # noqa: E501

        Gets or sets the type of section break for the specified object.  # noqa: E501

        :return: The section_start of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._section_start

    @section_start.setter
    def section_start(self, section_start):
        """Sets the section_start of this PageSetup.

        Gets or sets the type of section break for the specified object.  # noqa: E501

        :param section_start: The section_start of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["Continuous", "NewColumn", "NewPage", "EvenPage", "OddPage"]  # noqa: E501
        if not section_start.isdigit():
            if section_start not in allowed_values:
                raise ValueError(
                    "Invalid value for `section_start` ({0}), must be one of {1}"  # noqa: E501
                    .format(section_start, allowed_values))
            self._section_start = section_start
        else:
            self._section_start = allowed_values[int(section_start) if six.PY3 else long(section_start)]

    @property
    def suppress_endnotes(self):
        """Gets the suppress_endnotes of this PageSetup.  # noqa: E501

        Gets or sets a value indicating whether endnotes are printed at the end of the next section that doesn't suppress endnotes. Suppressed endnotes are printed before the endnotes in that section.  # noqa: E501

        :return: The suppress_endnotes of this PageSetup.  # noqa: E501
        :rtype: bool
        """
        return self._suppress_endnotes

    @suppress_endnotes.setter
    def suppress_endnotes(self, suppress_endnotes):
        """Sets the suppress_endnotes of this PageSetup.

        Gets or sets a value indicating whether endnotes are printed at the end of the next section that doesn't suppress endnotes. Suppressed endnotes are printed before the endnotes in that section.  # noqa: E501

        :param suppress_endnotes: The suppress_endnotes of this PageSetup.  # noqa: E501
        :type: bool
        """
        self._suppress_endnotes = suppress_endnotes

    @property
    def top_margin(self):
        """Gets the top_margin of this PageSetup.  # noqa: E501

        Gets or sets the distance (in points) between the top edge of the page and the top boundary of the body text.  # noqa: E501

        :return: The top_margin of this PageSetup.  # noqa: E501
        :rtype: float
        """
        return self._top_margin

    @top_margin.setter
    def top_margin(self, top_margin):
        """Sets the top_margin of this PageSetup.

        Gets or sets the distance (in points) between the top edge of the page and the top boundary of the body text.  # noqa: E501

        :param top_margin: The top_margin of this PageSetup.  # noqa: E501
        :type: float
        """
        self._top_margin = top_margin

    @property
    def vertical_alignment(self):
        """Gets the vertical_alignment of this PageSetup.  # noqa: E501

        Gets or sets the vertical alignment of text on each page in the document.or section.  # noqa: E501

        :return: The vertical_alignment of this PageSetup.  # noqa: E501
        :rtype: str
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """Sets the vertical_alignment of this PageSetup.

        Gets or sets the vertical alignment of text on each page in the document.or section.  # noqa: E501

        :param vertical_alignment: The vertical_alignment of this PageSetup.  # noqa: E501
        :type: str
        """
        allowed_values = ["Top", "Center", "Justify", "Bottom"]  # noqa: E501
        if not vertical_alignment.isdigit():
            if vertical_alignment not in allowed_values:
                raise ValueError(
                    "Invalid value for `vertical_alignment` ({0}), must be one of {1}"  # noqa: E501
                    .format(vertical_alignment, allowed_values))
            self._vertical_alignment = vertical_alignment
        else:
            self._vertical_alignment = allowed_values[int(vertical_alignment) if six.PY3 else long(vertical_alignment)]


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PageSetup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="drawing_object_insert.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class DrawingObjectInsert(object):
    """Drawing object element for insert.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'position': 'NewDocumentPosition',
        'relative_horizontal_position': 'str',
        'left': 'float',
        'relative_vertical_position': 'str',
        'top': 'float',
        'width': 'float',
        'height': 'float',
        'wrap_type': 'str'
    }

    attribute_map = {
        'position': 'Position',
        'relative_horizontal_position': 'RelativeHorizontalPosition',
        'left': 'Left',
        'relative_vertical_position': 'RelativeVerticalPosition',
        'top': 'Top',
        'width': 'Width',
        'height': 'Height',
        'wrap_type': 'WrapType'
    }

    def __init__(self, position=None, relative_horizontal_position=None, left=None, relative_vertical_position=None, top=None, width=None, height=None, wrap_type=None):  # noqa: E501
        """DrawingObjectInsert - a model defined in Swagger"""  # noqa: E501

        self._position = None
        self._relative_horizontal_position = None
        self._left = None
        self._relative_vertical_position = None
        self._top = None
        self._width = None
        self._height = None
        self._wrap_type = None
        self.discriminator = None

        if position is not None:
            self.position = position
        if relative_horizontal_position is not None:
            self.relative_horizontal_position = relative_horizontal_position
        if left is not None:
            self.left = left
        if relative_vertical_position is not None:
            self.relative_vertical_position = relative_vertical_position
        if top is not None:
            self.top = top
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if wrap_type is not None:
            self.wrap_type = wrap_type

    @property
    def position(self):
        """Gets the position of this DrawingObjectInsert.  # noqa: E501

        Gets or sets the position, before which the DrawingObject will be inserted.  # noqa: E501

        :return: The position of this DrawingObjectInsert.  # noqa: E501
        :rtype: NewDocumentPosition
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this DrawingObjectInsert.

        Gets or sets the position, before which the DrawingObject will be inserted.  # noqa: E501

        :param position: The position of this DrawingObjectInsert.  # noqa: E501
        :type: NewDocumentPosition
        """
        self._position = position

    @property
    def relative_horizontal_position(self):
        """Gets the relative_horizontal_position of this DrawingObjectInsert.  # noqa: E501

        Gets or sets the relative horizontal position, from which the distance to the image is measured.  # noqa: E501

        :return: The relative_horizontal_position of this DrawingObjectInsert.  # noqa: E501
        :rtype: str
        """
        return self._relative_horizontal_position

    @relative_horizontal_position.setter
    def relative_horizontal_position(self, relative_horizontal_position):
        """Sets the relative_horizontal_position of this DrawingObjectInsert.

        Gets or sets the relative horizontal position, from which the distance to the image is measured.  # noqa: E501

        :param relative_horizontal_position: The relative_horizontal_position of this DrawingObjectInsert.  # noqa: E501
        :type: str
        """
        allowed_values = ["Margin", "Page", "Column", "Default", "Character", "LeftMargin", "RightMargin", "InsideMargin", "OutsideMargin"]  # noqa: E501
        if not relative_horizontal_position.isdigit():
            if relative_horizontal_position not in allowed_values:
                raise ValueError(
                    "Invalid value for `relative_horizontal_position` ({0}), must be one of {1}"  # noqa: E501
                    .format(relative_horizontal_position, allowed_values))
            self._relative_horizontal_position = relative_horizontal_position
        else:
            self._relative_horizontal_position = allowed_values[int(relative_horizontal_position) if six.PY3 else long(relative_horizontal_position)]

    @property
    def left(self):
        """Gets the left of this DrawingObjectInsert.  # noqa: E501

        Gets or sets the distance in points from the origin to the left side of the image.  # noqa: E501

        :return: The left of this DrawingObjectInsert.  # noqa: E501
        :rtype: float
        """
        return self._left

    @left.setter
    def left(self, left):
        """Sets the left of this DrawingObjectInsert.

        Gets or sets the distance in points from the origin to the left side of the image.  # noqa: E501

        :param left: The left of this DrawingObjectInsert.  # noqa: E501
        :type: float
        """
        self._left = left

    @property
    def relative_vertical_position(self):
        """Gets the relative_vertical_position of this DrawingObjectInsert.  # noqa: E501

        Gets or sets the relative vertical position, from which the distance to the image is measured.  # noqa: E501

        :return: The relative_vertical_position of this DrawingObjectInsert.  # noqa: E501
        :rtype: str
        """
        return self._relative_vertical_position

    @relative_vertical_position.setter
    def relative_vertical_position(self, relative_vertical_position):
        """Sets the relative_vertical_position of this DrawingObjectInsert.

        Gets or sets the relative vertical position, from which the distance to the image is measured.  # noqa: E501

        :param relative_vertical_position: The relative_vertical_position of this DrawingObjectInsert.  # noqa: E501
        :type: str
        """
        allowed_values = ["Margin", "TableDefault", "Page", "Paragraph", "TextFrameDefault", "Line", "TopMargin", "BottomMargin", "InsideMargin", "OutsideMargin"]  # noqa: E501
        if not relative_vertical_position.isdigit():
            if relative_vertical_position not in allowed_values:
                raise ValueError(
                    "Invalid value for `relative_vertical_position` ({0}), must be one of {1}"  # noqa: E501
                    .format(relative_vertical_position, allowed_values))
            self._relative_vertical_position = relative_vertical_position
        else:
            self._relative_vertical_position = allowed_values[int(relative_vertical_position) if six.PY3 else long(relative_vertical_position)]

    @property
    def top(self):
        """Gets the top of this DrawingObjectInsert.  # noqa: E501

        Gets or sets the distance in points from the origin to the top side of the image.  # noqa: E501

        :return: The top of this DrawingObjectInsert.  # noqa: E501
        :rtype: float
        """
        return self._top

    @top.setter
    def top(self, top):
        """Sets the top of this DrawingObjectInsert.

        Gets or sets the distance in points from the origin to the top side of the image.  # noqa: E501

        :param top: The top of this DrawingObjectInsert.  # noqa: E501
        :type: float
        """
        self._top = top

    @property
    def width(self):
        """Gets the width of this DrawingObjectInsert.  # noqa: E501

        Gets or sets the width of the DrawingObjects in points.  # noqa: E501

        :return: The width of this DrawingObjectInsert.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this DrawingObjectInsert.

        Gets or sets the width of the DrawingObjects in points.  # noqa: E501

        :param width: The width of this DrawingObjectInsert.  # noqa: E501
        :type: float
        """
        self._width = width

    @property
    def height(self):
        """Gets the height of this DrawingObjectInsert.  # noqa: E501

        Gets or sets the height of the DrawingObject in points.  # noqa: E501

        :return: The height of this DrawingObjectInsert.  # noqa: E501
        :rtype: float
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this DrawingObjectInsert.

        Gets or sets the height of the DrawingObject in points.  # noqa: E501

        :param height: The height of this DrawingObjectInsert.  # noqa: E501
        :type: float
        """
        self._height = height

    @property
    def wrap_type(self):
        """Gets the wrap_type of this DrawingObjectInsert.  # noqa: E501

        Gets or sets the option indicating how to wrap text around the image.  # noqa: E501

        :return: The wrap_type of this DrawingObjectInsert.  # noqa: E501
        :rtype: str
        """
        return self._wrap_type

    @wrap_type.setter
    def wrap_type(self, wrap_type):
        """Sets the wrap_type of this DrawingObjectInsert.

        Gets or sets the option indicating how to wrap text around the image.  # noqa: E501

        :param wrap_type: The wrap_type of this DrawingObjectInsert.  # noqa: E501
        :type: str
        """
        allowed_values = ["Inline", "TopBottom", "Square", "None", "Tight", "Through"]  # noqa: E501
        if not wrap_type.isdigit():
            if wrap_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `wrap_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(wrap_type, allowed_values))
            self._wrap_type = wrap_type
        else:
            self._wrap_type = allowed_values[int(wrap_type) if six.PY3 else long(wrap_type)]


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DrawingObjectInsert):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="border.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class Border(object):
    """Represents a border of an object. Borders can be applied to various document elements including paragraph, run of text inside a paragraph or a table cell.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'border_type': 'str',
        'color': 'XmlColor',
        'distance_from_text': 'float',
        'line_style': 'str',
        'line_width': 'float',
        'shadow': 'bool'
    }

    attribute_map = {
        'link': 'Link',
        'border_type': 'BorderType',
        'color': 'Color',
        'distance_from_text': 'DistanceFromText',
        'line_style': 'LineStyle',
        'line_width': 'LineWidth',
        'shadow': 'Shadow'
    }

    def __init__(self, link=None, border_type=None, color=None, distance_from_text=None, line_style=None, line_width=None, shadow=None):  # noqa: E501
        """Border - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._border_type = None
        self._color = None
        self._distance_from_text = None
        self._line_style = None
        self._line_width = None
        self._shadow = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if border_type is not None:
            self.border_type = border_type
        if color is not None:
            self.color = color
        if distance_from_text is not None:
            self.distance_from_text = distance_from_text
        if line_style is not None:
            self.line_style = line_style
        if line_width is not None:
            self.line_width = line_width
        if shadow is not None:
            self.shadow = shadow

    @property
    def link(self):
        """Gets the link of this Border.  # noqa: E501

        Gets or sets the link to the document.  # noqa: E501

        :return: The link of this Border.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this Border.

        Gets or sets the link to the document.  # noqa: E501

        :param link: The link of this Border.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def border_type(self):
        """Gets the border_type of this Border.  # noqa: E501

        Gets or sets the border type.  # noqa: E501

        :return: The border_type of this Border.  # noqa: E501
        :rtype: str
        """
        return self._border_type

    @border_type.setter
    def border_type(self, border_type):
        """Sets the border_type of this Border.

        Gets or sets the border type.  # noqa: E501

        :param border_type: The border_type of this Border.  # noqa: E501
        :type: str
        """
        allowed_values = ["Bottom", "Left", "Right", "Top", "Horizontal", "Vertical", "DiagonalDown", "DiagonalUp", "None"]  # noqa: E501
        if not border_type.isdigit():
            if border_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `border_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(border_type, allowed_values))
            self._border_type = border_type
        else:
            self._border_type = allowed_values[int(border_type) if six.PY3 else long(border_type)]

    @property
    def color(self):
        """Gets the color of this Border.  # noqa: E501

        Gets or sets the border color.  # noqa: E501

        :return: The color of this Border.  # noqa: E501
        :rtype: XmlColor
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this Border.

        Gets or sets the border color.  # noqa: E501

        :param color: The color of this Border.  # noqa: E501
        :type: XmlColor
        """
        self._color = color

    @property
    def distance_from_text(self):
        """Gets the distance_from_text of this Border.  # noqa: E501

        Gets or sets the distance of the border from text or from the page edge in points. Has no effect and will be automatically reset to zero for borders of table cells.  # noqa: E501

        :return: The distance_from_text of this Border.  # noqa: E501
        :rtype: float
        """
        return self._distance_from_text

    @distance_from_text.setter
    def distance_from_text(self, distance_from_text):
        """Sets the distance_from_text of this Border.

        Gets or sets the distance of the border from text or from the page edge in points. Has no effect and will be automatically reset to zero for borders of table cells.  # noqa: E501

        :param distance_from_text: The distance_from_text of this Border.  # noqa: E501
        :type: float
        """
        self._distance_from_text = distance_from_text

    @property
    def line_style(self):
        """Gets the line_style of this Border.  # noqa: E501

        Gets or sets the border style. If you set line style to none, then line width is automatically changed to zero.  # noqa: E501

        :return: The line_style of this Border.  # noqa: E501
        :rtype: str
        """
        return self._line_style

    @line_style.setter
    def line_style(self, line_style):
        """Sets the line_style of this Border.

        Gets or sets the border style. If you set line style to none, then line width is automatically changed to zero.  # noqa: E501

        :param line_style: The line_style of this Border.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Single", "Thick", "Double", "Hairline", "Dot", "DashLargeGap", "DotDash", "DotDotDash", "Triple", "ThinThickSmallGap", "ThickThinSmallGap", "ThinThickThinSmallGap", "ThinThickMediumGap", "ThickThinMediumGap", "ThinThickThinMediumGap", "ThinThickLargeGap", "ThickThinLargeGap", "ThinThickThinLargeGap", "Wave", "DoubleWave", "DashSmallGap", "DashDotStroker", "Emboss3D", "Engrave3D", "Outset", "Inset"]  # noqa: E501
        if not line_style.isdigit():
            if line_style not in allowed_values:
                raise ValueError(
                    "Invalid value for `line_style` ({0}), must be one of {1}"  # noqa: E501
                    .format(line_style, allowed_values))
            self._line_style = line_style
        else:
            self._line_style = allowed_values[int(line_style) if six.PY3 else long(line_style)]

    @property
    def line_width(self):
        """Gets the line_width of this Border.  # noqa: E501

        Gets or sets the border width in points. If you set line width greater than zero when line style is none, the line style is automatically changed to single line.  # noqa: E501

        :return: The line_width of this Border.  # noqa: E501
        :rtype: float
        """
        return self._line_width

    @line_width.setter
    def line_width(self, line_width):
        """Sets the line_width of this Border.

        Gets or sets the border width in points. If you set line width greater than zero when line style is none, the line style is automatically changed to single line.  # noqa: E501

        :param line_width: The line_width of this Border.  # noqa: E501
        :type: float
        """
        self._line_width = line_width

    @property
    def shadow(self):
        """Gets the shadow of this Border.  # noqa: E501

        Gets or sets a value indicating whether the border has a shadow. In Microsoft Word, for a border to have a shadow, the borders on all four sides (left, top, right and bottom) should be of the same type, width, color and all should have the Shadow property set to true.  # noqa: E501

        :return: The shadow of this Border.  # noqa: E501
        :rtype: bool
        """
        return self._shadow

    @shadow.setter
    def shadow(self, shadow):
        """Sets the shadow of this Border.

        Gets or sets a value indicating whether the border has a shadow. In Microsoft Word, for a border to have a shadow, the borders on all four sides (left, top, right and bottom) should be of the same type, width, color and all should have the Shadow property set to true.  # noqa: E501

        :param shadow: The shadow of this Border.  # noqa: E501
        :type: bool
        """
        self._shadow = shadow


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Border):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="document.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class Document(object):
    """Represents Words document DTO.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'list[Link]',
        'document_properties': 'DocumentProperties',
        'file_name': 'str',
        'is_encrypted': 'bool',
        'is_signed': 'bool',
        'source_format': 'str'
    }

    attribute_map = {
        'links': 'Links',
        'document_properties': 'DocumentProperties',
        'file_name': 'FileName',
        'is_encrypted': 'IsEncrypted',
        'is_signed': 'IsSigned',
        'source_format': 'SourceFormat'
    }

    def __init__(self, links=None, document_properties=None, file_name=None, is_encrypted=None, is_signed=None, source_format=None):  # noqa: E501
        """Document - a model defined in Swagger"""  # noqa: E501

        self._links = None
        self._document_properties = None
        self._file_name = None
        self._is_encrypted = None
        self._is_signed = None
        self._source_format = None
        self.discriminator = None

        if links is not None:
            self.links = links
        if document_properties is not None:
            self.document_properties = document_properties
        if file_name is not None:
            self.file_name = file_name
        if is_encrypted is not None:
            self.is_encrypted = is_encrypted
        if is_signed is not None:
            self.is_signed = is_signed
        if source_format is not None:
            self.source_format = source_format

    @property
    def links(self):
        """Gets the links of this Document.  # noqa: E501

        Gets or sets the list of links that originate from this document.  # noqa: E501

        :return: The links of this Document.  # noqa: E501
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this Document.

        Gets or sets the list of links that originate from this document.  # noqa: E501

        :param links: The links of this Document.  # noqa: E501
        :type: list[Link]
        """
        self._links = links

    @property
    def document_properties(self):
        """Gets the document_properties of this Document.  # noqa: E501

        Gets or sets the document properties.  # noqa: E501

        :return: The document_properties of this Document.  # noqa: E501
        :rtype: DocumentProperties
        """
        return self._document_properties

    @document_properties.setter
    def document_properties(self, document_properties):
        """Sets the document_properties of this Document.

        Gets or sets the document properties.  # noqa: E501

        :param document_properties: The document_properties of this Document.  # noqa: E501
        :type: DocumentProperties
        """
        self._document_properties = document_properties

    @property
    def file_name(self):
        """Gets the file_name of this Document.  # noqa: E501

        Gets or sets the name of the file.  # noqa: E501

        :return: The file_name of this Document.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this Document.

        Gets or sets the name of the file.  # noqa: E501

        :param file_name: The file_name of this Document.  # noqa: E501
        :type: str
        """
        self._file_name = file_name

    @property
    def is_encrypted(self):
        """Gets the is_encrypted of this Document.  # noqa: E501

        Gets or sets a value indicating whether the document is encrypted and requires a password to open.  # noqa: E501

        :return: The is_encrypted of this Document.  # noqa: E501
        :rtype: bool
        """
        return self._is_encrypted

    @is_encrypted.setter
    def is_encrypted(self, is_encrypted):
        """Sets the is_encrypted of this Document.

        Gets or sets a value indicating whether the document is encrypted and requires a password to open.  # noqa: E501

        :param is_encrypted: The is_encrypted of this Document.  # noqa: E501
        :type: bool
        """
        self._is_encrypted = is_encrypted

    @property
    def is_signed(self):
        """Gets the is_signed of this Document.  # noqa: E501

        Gets or sets a value indicating whether the document contains a digital signature. This property merely informs that a digital signature is present on a document, but it does not specify whether the signature is valid or not.  # noqa: E501

        :return: The is_signed of this Document.  # noqa: E501
        :rtype: bool
        """
        return self._is_signed

    @is_signed.setter
    def is_signed(self, is_signed):
        """Sets the is_signed of this Document.

        Gets or sets a value indicating whether the document contains a digital signature. This property merely informs that a digital signature is present on a document, but it does not specify whether the signature is valid or not.  # noqa: E501

        :param is_signed: The is_signed of this Document.  # noqa: E501
        :type: bool
        """
        self._is_signed = is_signed

    @property
    def source_format(self):
        """Gets the source_format of this Document.  # noqa: E501

        Gets or sets the original format of the document.  # noqa: E501

        :return: The source_format of this Document.  # noqa: E501
        :rtype: str
        """
        return self._source_format

    @source_format.setter
    def source_format(self, source_format):
        """Sets the source_format of this Document.

        Gets or sets the original format of the document.  # noqa: E501

        :param source_format: The source_format of this Document.  # noqa: E501
        :type: str
        """
        allowed_values = ["Unknown", "Doc", "Dot", "DocPreWord60", "Docx", "Docm", "Dotx", "Dotm", "FlatOpc", "Rtf", "WordML", "Html", "Mhtml", "Epub", "Text", "Odt", "Ott", "Pdf", "Xps", "Tiff", "Svg"]  # noqa: E501
        if not source_format.isdigit():
            if source_format not in allowed_values:
                raise ValueError(
                    "Invalid value for `source_format` ({0}), must be one of {1}"  # noqa: E501
                    .format(source_format, allowed_values))
            self._source_format = source_format
        else:
            self._source_format = allowed_values[int(source_format) if six.PY3 else long(source_format)]


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Document):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="font.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class Font(object):
    """DTO container with a font element.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'link': 'WordsApiLink',
        'all_caps': 'bool',
        'bidi': 'bool',
        'bold': 'bool',
        'bold_bi': 'bool',
        'border': 'Border',
        'color': 'XmlColor',
        'complex_script': 'bool',
        'double_strike_through': 'bool',
        'emboss': 'bool',
        'engrave': 'bool',
        'hidden': 'bool',
        'highlight_color': 'XmlColor',
        'italic': 'bool',
        'italic_bi': 'bool',
        'kerning': 'float',
        'locale_id': 'int',
        'locale_id_bi': 'int',
        'locale_id_far_east': 'int',
        'name': 'str',
        'name_ascii': 'str',
        'name_bi': 'str',
        'name_far_east': 'str',
        'name_other': 'str',
        'no_proofing': 'bool',
        'outline': 'bool',
        'position': 'float',
        'scaling': 'int',
        'shadow': 'bool',
        'size': 'float',
        'size_bi': 'float',
        'small_caps': 'bool',
        'spacing': 'float',
        'strike_through': 'bool',
        'style_identifier': 'str',
        'style_name': 'str',
        'subscript': 'bool',
        'superscript': 'bool',
        'text_effect': 'str',
        'underline': 'str',
        'underline_color': 'XmlColor'
    }

    attribute_map = {
        'link': 'Link',
        'all_caps': 'AllCaps',
        'bidi': 'Bidi',
        'bold': 'Bold',
        'bold_bi': 'BoldBi',
        'border': 'Border',
        'color': 'Color',
        'complex_script': 'ComplexScript',
        'double_strike_through': 'DoubleStrikeThrough',
        'emboss': 'Emboss',
        'engrave': 'Engrave',
        'hidden': 'Hidden',
        'highlight_color': 'HighlightColor',
        'italic': 'Italic',
        'italic_bi': 'ItalicBi',
        'kerning': 'Kerning',
        'locale_id': 'LocaleId',
        'locale_id_bi': 'LocaleIdBi',
        'locale_id_far_east': 'LocaleIdFarEast',
        'name': 'Name',
        'name_ascii': 'NameAscii',
        'name_bi': 'NameBi',
        'name_far_east': 'NameFarEast',
        'name_other': 'NameOther',
        'no_proofing': 'NoProofing',
        'outline': 'Outline',
        'position': 'Position',
        'scaling': 'Scaling',
        'shadow': 'Shadow',
        'size': 'Size',
        'size_bi': 'SizeBi',
        'small_caps': 'SmallCaps',
        'spacing': 'Spacing',
        'strike_through': 'StrikeThrough',
        'style_identifier': 'StyleIdentifier',
        'style_name': 'StyleName',
        'subscript': 'Subscript',
        'superscript': 'Superscript',
        'text_effect': 'TextEffect',
        'underline': 'Underline',
        'underline_color': 'UnderlineColor'
    }

    def __init__(self, link=None, all_caps=None, bidi=None, bold=None, bold_bi=None, border=None, color=None, complex_script=None, double_strike_through=None, emboss=None, engrave=None, hidden=None, highlight_color=None, italic=None, italic_bi=None, kerning=None, locale_id=None, locale_id_bi=None, locale_id_far_east=None, name=None, name_ascii=None, name_bi=None, name_far_east=None, name_other=None, no_proofing=None, outline=None, position=None, scaling=None, shadow=None, size=None, size_bi=None, small_caps=None, spacing=None, strike_through=None, style_identifier=None, style_name=None, subscript=None, superscript=None, text_effect=None, underline=None, underline_color=None):  # noqa: E501
        """Font - a model defined in Swagger"""  # noqa: E501

        self._link = None
        self._all_caps = None
        self._bidi = None
        self._bold = None
        self._bold_bi = None
        self._border = None
        self._color = None
        self._complex_script = None
        self._double_strike_through = None
        self._emboss = None
        self._engrave = None
        self._hidden = None
        self._highlight_color = None
        self._italic = None
        self._italic_bi = None
        self._kerning = None
        self._locale_id = None
        self._locale_id_bi = None
        self._locale_id_far_east = None
        self._name = None
        self._name_ascii = None
        self._name_bi = None
        self._name_far_east = None
        self._name_other = None
        self._no_proofing = None
        self._outline = None
        self._position = None
        self._scaling = None
        self._shadow = None
        self._size = None
        self._size_bi = None
        self._small_caps = None
        self._spacing = None
        self._strike_through = None
        self._style_identifier = None
        self._style_name = None
        self._subscript = None
        self._superscript = None
        self._text_effect = None
        self._underline = None
        self._underline_color = None
        self.discriminator = None

        if link is not None:
            self.link = link
        if all_caps is not None:
            self.all_caps = all_caps
        if bidi is not None:
            self.bidi = bidi
        if bold is not None:
            self.bold = bold
        if bold_bi is not None:
            self.bold_bi = bold_bi
        if border is not None:
            self.border = border
        if color is not None:
            self.color = color
        if complex_script is not None:
            self.complex_script = complex_script
        if double_strike_through is not None:
            self.double_strike_through = double_strike_through
        if emboss is not None:
            self.emboss = emboss
        if engrave is not None:
            self.engrave = engrave
        if hidden is not None:
            self.hidden = hidden
        if highlight_color is not None:
            self.highlight_color = highlight_color
        if italic is not None:
            self.italic = italic
        if italic_bi is not None:
            self.italic_bi = italic_bi
        if kerning is not None:
            self.kerning = kerning
        if locale_id is not None:
            self.locale_id = locale_id
        if locale_id_bi is not None:
            self.locale_id_bi = locale_id_bi
        if locale_id_far_east is not None:
            self.locale_id_far_east = locale_id_far_east
        if name is not None:
            self.name = name
        if name_ascii is not None:
            self.name_ascii = name_ascii
        if name_bi is not None:
            self.name_bi = name_bi
        if name_far_east is not None:
            self.name_far_east = name_far_east
        if name_other is not None:
            self.name_other = name_other
        if no_proofing is not None:
            self.no_proofing = no_proofing
        if outline is not None:
            self.outline = outline
        if position is not None:
            self.position = position
        if scaling is not None:
            self.scaling = scaling
        if shadow is not None:
            self.shadow = shadow
        if size is not None:
            self.size = size
        if size_bi is not None:
            self.size_bi = size_bi
        if small_caps is not None:
            self.small_caps = small_caps
        if spacing is not None:
            self.spacing = spacing
        if strike_through is not None:
            self.strike_through = strike_through
        if style_identifier is not None:
            self.style_identifier = style_identifier
        if style_name is not None:
            self.style_name = style_name
        if subscript is not None:
            self.subscript = subscript
        if superscript is not None:
            self.superscript = superscript
        if text_effect is not None:
            self.text_effect = text_effect
        if underline is not None:
            self.underline = underline
        if underline_color is not None:
            self.underline_color = underline_color

    @property
    def link(self):
        """Gets the link of this Font.  # noqa: E501

        Gets or sets the link to the document.  # noqa: E501

        :return: The link of this Font.  # noqa: E501
        :rtype: WordsApiLink
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this Font.

        Gets or sets the link to the document.  # noqa: E501

        :param link: The link of this Font.  # noqa: E501
        :type: WordsApiLink
        """
        self._link = link

    @property
    def all_caps(self):
        """Gets the all_caps of this Font.  # noqa: E501

        Gets or sets a value indicating whether the font is formatted as all capital letters.  # noqa: E501

        :return: The all_caps of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._all_caps

    @all_caps.setter
    def all_caps(self, all_caps):
        """Sets the all_caps of this Font.

        Gets or sets a value indicating whether the font is formatted as all capital letters.  # noqa: E501

        :param all_caps: The all_caps of this Font.  # noqa: E501
        :type: bool
        """
        self._all_caps = all_caps

    @property
    def bidi(self):
        """Gets the bidi of this Font.  # noqa: E501

        Gets or sets a value indicating whether the contents of this run shall have right-to-left characteristics. This property, when on, shall not be used with strongly left-to-right text. Any behavior under that condition is unspecified. This property, when off, shall not be used with strong right-to-left text. Any behavior under that condition is unspecified.When the contents of this run are displayed, all characters shall be treated as complex script characters for formatting purposes. This means that BoldBi, ItalicBi, SizeBi and a corresponding font name will be used when rendering this run.Also, when the contents of this run are displayed, this property acts as a right-to-left override for characters which are classified as "weak types" and "neutral types".  # noqa: E501

        :return: The bidi of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._bidi

    @bidi.setter
    def bidi(self, bidi):
        """Sets the bidi of this Font.

        Gets or sets a value indicating whether the contents of this run shall have right-to-left characteristics. This property, when on, shall not be used with strongly left-to-right text. Any behavior under that condition is unspecified. This property, when off, shall not be used with strong right-to-left text. Any behavior under that condition is unspecified.When the contents of this run are displayed, all characters shall be treated as complex script characters for formatting purposes. This means that BoldBi, ItalicBi, SizeBi and a corresponding font name will be used when rendering this run.Also, when the contents of this run are displayed, this property acts as a right-to-left override for characters which are classified as "weak types" and "neutral types".  # noqa: E501

        :param bidi: The bidi of this Font.  # noqa: E501
        :type: bool
        """
        self._bidi = bidi

    @property
    def bold(self):
        """Gets the bold of this Font.  # noqa: E501

        Gets or sets a value indicating whether the font is formatted as bold.  # noqa: E501

        :return: The bold of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._bold

    @bold.setter
    def bold(self, bold):
        """Sets the bold of this Font.

        Gets or sets a value indicating whether the font is formatted as bold.  # noqa: E501

        :param bold: The bold of this Font.  # noqa: E501
        :type: bool
        """
        self._bold = bold

    @property
    def bold_bi(self):
        """Gets the bold_bi of this Font.  # noqa: E501

        Gets or sets a value indicating whether the right-to-left text is formatted as bold.  # noqa: E501

        :return: The bold_bi of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._bold_bi

    @bold_bi.setter
    def bold_bi(self, bold_bi):
        """Sets the bold_bi of this Font.

        Gets or sets a value indicating whether the right-to-left text is formatted as bold.  # noqa: E501

        :param bold_bi: The bold_bi of this Font.  # noqa: E501
        :type: bool
        """
        self._bold_bi = bold_bi

    @property
    def border(self):
        """Gets the border of this Font.  # noqa: E501

        Gets or sets the border object, that specifies border for the font.  # noqa: E501

        :return: The border of this Font.  # noqa: E501
        :rtype: Border
        """
        return self._border

    @border.setter
    def border(self, border):
        """Sets the border of this Font.

        Gets or sets the border object, that specifies border for the font.  # noqa: E501

        :param border: The border of this Font.  # noqa: E501
        :type: Border
        """
        self._border = border

    @property
    def color(self):
        """Gets the color of this Font.  # noqa: E501

        Gets or sets the color of the font.  # noqa: E501

        :return: The color of this Font.  # noqa: E501
        :rtype: XmlColor
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this Font.

        Gets or sets the color of the font.  # noqa: E501

        :param color: The color of this Font.  # noqa: E501
        :type: XmlColor
        """
        self._color = color

    @property
    def complex_script(self):
        """Gets the complex_script of this Font.  # noqa: E501

        Gets or sets a value indicating whether the contents of this run shall be treated as complex script text regardless of their Unicode character values when determining the formatting for this run.  # noqa: E501

        :return: The complex_script of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._complex_script

    @complex_script.setter
    def complex_script(self, complex_script):
        """Sets the complex_script of this Font.

        Gets or sets a value indicating whether the contents of this run shall be treated as complex script text regardless of their Unicode character values when determining the formatting for this run.  # noqa: E501

        :param complex_script: The complex_script of this Font.  # noqa: E501
        :type: bool
        """
        self._complex_script = complex_script

    @property
    def double_strike_through(self):
        """Gets the double_strike_through of this Font.  # noqa: E501

        Gets or sets a value indicating whether the font is formatted as double strikethrough text.  # noqa: E501

        :return: The double_strike_through of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._double_strike_through

    @double_strike_through.setter
    def double_strike_through(self, double_strike_through):
        """Sets the double_strike_through of this Font.

        Gets or sets a value indicating whether the font is formatted as double strikethrough text.  # noqa: E501

        :param double_strike_through: The double_strike_through of this Font.  # noqa: E501
        :type: bool
        """
        self._double_strike_through = double_strike_through

    @property
    def emboss(self):
        """Gets the emboss of this Font.  # noqa: E501

        Gets or sets a value indicating whether the font is formatted as embossed.  # noqa: E501

        :return: The emboss of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._emboss

    @emboss.setter
    def emboss(self, emboss):
        """Sets the emboss of this Font.

        Gets or sets a value indicating whether the font is formatted as embossed.  # noqa: E501

        :param emboss: The emboss of this Font.  # noqa: E501
        :type: bool
        """
        self._emboss = emboss

    @property
    def engrave(self):
        """Gets the engrave of this Font.  # noqa: E501

        Gets or sets a value indicating whether the font is formatted as engraved.  # noqa: E501

        :return: The engrave of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._engrave

    @engrave.setter
    def engrave(self, engrave):
        """Sets the engrave of this Font.

        Gets or sets a value indicating whether the font is formatted as engraved.  # noqa: E501

        :param engrave: The engrave of this Font.  # noqa: E501
        :type: bool
        """
        self._engrave = engrave

    @property
    def hidden(self):
        """Gets the hidden of this Font.  # noqa: E501

        Gets or sets a value indicating whether the font is formatted as hidden text.  # noqa: E501

        :return: The hidden of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this Font.

        Gets or sets a value indicating whether the font is formatted as hidden text.  # noqa: E501

        :param hidden: The hidden of this Font.  # noqa: E501
        :type: bool
        """
        self._hidden = hidden

    @property
    def highlight_color(self):
        """Gets the highlight_color of this Font.  # noqa: E501

        Gets or sets the highlight (marker) color.  # noqa: E501

        :return: The highlight_color of this Font.  # noqa: E501
        :rtype: XmlColor
        """
        return self._highlight_color

    @highlight_color.setter
    def highlight_color(self, highlight_color):
        """Sets the highlight_color of this Font.

        Gets or sets the highlight (marker) color.  # noqa: E501

        :param highlight_color: The highlight_color of this Font.  # noqa: E501
        :type: XmlColor
        """
        self._highlight_color = highlight_color

    @property
    def italic(self):
        """Gets the italic of this Font.  # noqa: E501

        Gets or sets a value indicating whether the font is formatted as italic.  # noqa: E501

        :return: The italic of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._italic

    @italic.setter
    def italic(self, italic):
        """Sets the italic of this Font.

        Gets or sets a value indicating whether the font is formatted as italic.  # noqa: E501

        :param italic: The italic of this Font.  # noqa: E501
        :type: bool
        """
        self._italic = italic

    @property
    def italic_bi(self):
        """Gets the italic_bi of this Font.  # noqa: E501

        Gets or sets a value indicating whether the right-to-left text is formatted as italic.  # noqa: E501

        :return: The italic_bi of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._italic_bi

    @italic_bi.setter
    def italic_bi(self, italic_bi):
        """Sets the italic_bi of this Font.

        Gets or sets a value indicating whether the right-to-left text is formatted as italic.  # noqa: E501

        :param italic_bi: The italic_bi of this Font.  # noqa: E501
        :type: bool
        """
        self._italic_bi = italic_bi

    @property
    def kerning(self):
        """Gets the kerning of this Font.  # noqa: E501

        Gets or sets the font size at which kerning starts.  # noqa: E501

        :return: The kerning of this Font.  # noqa: E501
        :rtype: float
        """
        return self._kerning

    @kerning.setter
    def kerning(self, kerning):
        """Sets the kerning of this Font.

        Gets or sets the font size at which kerning starts.  # noqa: E501

        :param kerning: The kerning of this Font.  # noqa: E501
        :type: float
        """
        self._kerning = kerning

    @property
    def locale_id(self):
        """Gets the locale_id of this Font.  # noqa: E501

        Gets or sets the locale identifier (language) of the formatted characters. For the list of locale identifiers see http://www.microsoft.com/globaldev/reference/lcid-all.mspx.  # noqa: E501

        :return: The locale_id of this Font.  # noqa: E501
        :rtype: int
        """
        return self._locale_id

    @locale_id.setter
    def locale_id(self, locale_id):
        """Sets the locale_id of this Font.

        Gets or sets the locale identifier (language) of the formatted characters. For the list of locale identifiers see http://www.microsoft.com/globaldev/reference/lcid-all.mspx.  # noqa: E501

        :param locale_id: The locale_id of this Font.  # noqa: E501
        :type: int
        """
        self._locale_id = locale_id

    @property
    def locale_id_bi(self):
        """Gets the locale_id_bi of this Font.  # noqa: E501

        Gets or sets the locale identifier (language) of the formatted right-to-left characters. For the list of locale identifiers see http://www.microsoft.com/globaldev/reference/lcid-all.mspx.  # noqa: E501

        :return: The locale_id_bi of this Font.  # noqa: E501
        :rtype: int
        """
        return self._locale_id_bi

    @locale_id_bi.setter
    def locale_id_bi(self, locale_id_bi):
        """Sets the locale_id_bi of this Font.

        Gets or sets the locale identifier (language) of the formatted right-to-left characters. For the list of locale identifiers see http://www.microsoft.com/globaldev/reference/lcid-all.mspx.  # noqa: E501

        :param locale_id_bi: The locale_id_bi of this Font.  # noqa: E501
        :type: int
        """
        self._locale_id_bi = locale_id_bi

    @property
    def locale_id_far_east(self):
        """Gets the locale_id_far_east of this Font.  # noqa: E501

        Gets or sets the locale identifier (language) of the formatted Asian characters. For the list of locale identifiers see http://www.microsoft.com/globaldev/reference/lcid-all.mspx.  # noqa: E501

        :return: The locale_id_far_east of this Font.  # noqa: E501
        :rtype: int
        """
        return self._locale_id_far_east

    @locale_id_far_east.setter
    def locale_id_far_east(self, locale_id_far_east):
        """Sets the locale_id_far_east of this Font.

        Gets or sets the locale identifier (language) of the formatted Asian characters. For the list of locale identifiers see http://www.microsoft.com/globaldev/reference/lcid-all.mspx.  # noqa: E501

        :param locale_id_far_east: The locale_id_far_east of this Font.  # noqa: E501
        :type: int
        """
        self._locale_id_far_east = locale_id_far_east

    @property
    def name(self):
        """Gets the name of this Font.  # noqa: E501

        Gets or sets the name of the font.  # noqa: E501

        :return: The name of this Font.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Font.

        Gets or sets the name of the font.  # noqa: E501

        :param name: The name of this Font.  # noqa: E501
        :type: str
        """
        self._name = name

    @property
    def name_ascii(self):
        """Gets the name_ascii of this Font.  # noqa: E501

        Gets or sets the font used for Latin text (characters with character codes from 0 (zero) through 127).  # noqa: E501

        :return: The name_ascii of this Font.  # noqa: E501
        :rtype: str
        """
        return self._name_ascii

    @name_ascii.setter
    def name_ascii(self, name_ascii):
        """Sets the name_ascii of this Font.

        Gets or sets the font used for Latin text (characters with character codes from 0 (zero) through 127).  # noqa: E501

        :param name_ascii: The name_ascii of this Font.  # noqa: E501
        :type: str
        """
        self._name_ascii = name_ascii

    @property
    def name_bi(self):
        """Gets the name_bi of this Font.  # noqa: E501

        Gets or sets the name of the font in a right-to-left language document.  # noqa: E501

        :return: The name_bi of this Font.  # noqa: E501
        :rtype: str
        """
        return self._name_bi

    @name_bi.setter
    def name_bi(self, name_bi):
        """Sets the name_bi of this Font.

        Gets or sets the name of the font in a right-to-left language document.  # noqa: E501

        :param name_bi: The name_bi of this Font.  # noqa: E501
        :type: str
        """
        self._name_bi = name_bi

    @property
    def name_far_east(self):
        """Gets the name_far_east of this Font.  # noqa: E501

        Gets or sets the East Asian font name.  # noqa: E501

        :return: The name_far_east of this Font.  # noqa: E501
        :rtype: str
        """
        return self._name_far_east

    @name_far_east.setter
    def name_far_east(self, name_far_east):
        """Sets the name_far_east of this Font.

        Gets or sets the East Asian font name.  # noqa: E501

        :param name_far_east: The name_far_east of this Font.  # noqa: E501
        :type: str
        """
        self._name_far_east = name_far_east

    @property
    def name_other(self):
        """Gets the name_other of this Font.  # noqa: E501

        Gets or sets the font used for characters with character codes from 128 through 255.  # noqa: E501

        :return: The name_other of this Font.  # noqa: E501
        :rtype: str
        """
        return self._name_other

    @name_other.setter
    def name_other(self, name_other):
        """Sets the name_other of this Font.

        Gets or sets the font used for characters with character codes from 128 through 255.  # noqa: E501

        :param name_other: The name_other of this Font.  # noqa: E501
        :type: str
        """
        self._name_other = name_other

    @property
    def no_proofing(self):
        """Gets the no_proofing of this Font.  # noqa: E501

        Gets or sets a value indicating whether the formatted characters are not to be spell checked.  # noqa: E501

        :return: The no_proofing of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._no_proofing

    @no_proofing.setter
    def no_proofing(self, no_proofing):
        """Sets the no_proofing of this Font.

        Gets or sets a value indicating whether the formatted characters are not to be spell checked.  # noqa: E501

        :param no_proofing: The no_proofing of this Font.  # noqa: E501
        :type: bool
        """
        self._no_proofing = no_proofing

    @property
    def outline(self):
        """Gets the outline of this Font.  # noqa: E501

        Gets or sets a value indicating whether the font is formatted as outline.  # noqa: E501

        :return: The outline of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._outline

    @outline.setter
    def outline(self, outline):
        """Sets the outline of this Font.

        Gets or sets a value indicating whether the font is formatted as outline.  # noqa: E501

        :param outline: The outline of this Font.  # noqa: E501
        :type: bool
        """
        self._outline = outline

    @property
    def position(self):
        """Gets the position of this Font.  # noqa: E501

        Gets or sets the position of text (in points) relative to the base line. A positive number raises the text, and a negative number lowers it.  # noqa: E501

        :return: The position of this Font.  # noqa: E501
        :rtype: float
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this Font.

        Gets or sets the position of text (in points) relative to the base line. A positive number raises the text, and a negative number lowers it.  # noqa: E501

        :param position: The position of this Font.  # noqa: E501
        :type: float
        """
        self._position = position

    @property
    def scaling(self):
        """Gets the scaling of this Font.  # noqa: E501

        Gets or sets character width scaling in percent.  # noqa: E501

        :return: The scaling of this Font.  # noqa: E501
        :rtype: int
        """
        return self._scaling

    @scaling.setter
    def scaling(self, scaling):
        """Sets the scaling of this Font.

        Gets or sets character width scaling in percent.  # noqa: E501

        :param scaling: The scaling of this Font.  # noqa: E501
        :type: int
        """
        self._scaling = scaling

    @property
    def shadow(self):
        """Gets the shadow of this Font.  # noqa: E501

        Gets or sets a value indicating whether the font is formatted as shadowed.  # noqa: E501

        :return: The shadow of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._shadow

    @shadow.setter
    def shadow(self, shadow):
        """Sets the shadow of this Font.

        Gets or sets a value indicating whether the font is formatted as shadowed.  # noqa: E501

        :param shadow: The shadow of this Font.  # noqa: E501
        :type: bool
        """
        self._shadow = shadow

    @property
    def size(self):
        """Gets the size of this Font.  # noqa: E501

        Gets or sets the font size in points.  # noqa: E501

        :return: The size of this Font.  # noqa: E501
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Font.

        Gets or sets the font size in points.  # noqa: E501

        :param size: The size of this Font.  # noqa: E501
        :type: float
        """
        self._size = size

    @property
    def size_bi(self):
        """Gets the size_bi of this Font.  # noqa: E501

        Gets or sets the font size in points used in a right-to-left document.  # noqa: E501

        :return: The size_bi of this Font.  # noqa: E501
        :rtype: float
        """
        return self._size_bi

    @size_bi.setter
    def size_bi(self, size_bi):
        """Sets the size_bi of this Font.

        Gets or sets the font size in points used in a right-to-left document.  # noqa: E501

        :param size_bi: The size_bi of this Font.  # noqa: E501
        :type: float
        """
        self._size_bi = size_bi

    @property
    def small_caps(self):
        """Gets the small_caps of this Font.  # noqa: E501

        Gets or sets a value indicating whether the font is formatted as small capital letters.  # noqa: E501

        :return: The small_caps of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._small_caps

    @small_caps.setter
    def small_caps(self, small_caps):
        """Sets the small_caps of this Font.

        Gets or sets a value indicating whether the font is formatted as small capital letters.  # noqa: E501

        :param small_caps: The small_caps of this Font.  # noqa: E501
        :type: bool
        """
        self._small_caps = small_caps

    @property
    def spacing(self):
        """Gets the spacing of this Font.  # noqa: E501

        Gets or sets the spacing (in points) between characters.  # noqa: E501

        :return: The spacing of this Font.  # noqa: E501
        :rtype: float
        """
        return self._spacing

    @spacing.setter
    def spacing(self, spacing):
        """Sets the spacing of this Font.

        Gets or sets the spacing (in points) between characters.  # noqa: E501

        :param spacing: The spacing of this Font.  # noqa: E501
        :type: float
        """
        self._spacing = spacing

    @property
    def strike_through(self):
        """Gets the strike_through of this Font.  # noqa: E501

        Gets or sets a value indicating whether the font is formatted as strikethrough text.  # noqa: E501

        :return: The strike_through of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._strike_through

    @strike_through.setter
    def strike_through(self, strike_through):
        """Sets the strike_through of this Font.

        Gets or sets a value indicating whether the font is formatted as strikethrough text.  # noqa: E501

        :param strike_through: The strike_through of this Font.  # noqa: E501
        :type: bool
        """
        self._strike_through = strike_through

    @property
    def style_identifier(self):
        """Gets the style_identifier of this Font.  # noqa: E501

        Gets or sets the locale independent style identifier of the character style applied to this formatting.  # noqa: E501

        :return: The style_identifier of this Font.  # noqa: E501
        :rtype: str
        """
        return self._style_identifier

    @style_identifier.setter
    def style_identifier(self, style_identifier):
        """Sets the style_identifier of this Font.

        Gets or sets the locale independent style identifier of the character style applied to this formatting.  # noqa: E501

        :param style_identifier: The style_identifier of this Font.  # noqa: E501
        :type: str
        """
        allowed_values = ["Normal", "Heading1", "Heading2", "Heading3", "Heading4", "Heading5", "Heading6", "Heading7", "Heading8", "Heading9", "Index1", "Index2", "Index3", "Index4", "Index5", "Index6", "Index7", "Index8", "Index9", "Toc1", "Toc2", "Toc3", "Toc4", "Toc5", "Toc6", "Toc7", "Toc8", "Toc9", "NormalIndent", "FootnoteText", "CommentText", "Header", "Footer", "IndexHeading", "Caption", "TableOfFigures", "EnvelopeAddress", "EnvelopeReturn", "FootnoteReference", "CommentReference", "LineNumber", "PageNumber", "EndnoteReference", "EndnoteText", "TableOfAuthorities", "Macro", "ToaHeading", "List", "ListBullet", "ListNumber", "List2", "List3", "List4", "List5", "ListBullet2", "ListBullet3", "ListBullet4", "ListBullet5", "ListNumber2", "ListNumber3", "ListNumber4", "ListNumber5", "Title", "Closing", "Signature", "DefaultParagraphFont", "BodyText", "BodyTextInd", "ListContinue", "ListContinue2", "ListContinue3", "ListContinue4", "ListContinue5", "MessageHeader", "Subtitle", "Salutation", "Date", "BodyText1I", "BodyText1I2", "NoteHeading", "BodyText2", "BodyText3", "BodyTextInd2", "BodyTextInd3", "BlockText", "Hyperlink", "FollowedHyperlink", "Strong", "Emphasis", "DocumentMap", "PlainText", "EmailSignature", "HtmlTopOfForm", "HtmlBottomOfForm", "NormalWeb", "HtmlAcronym", "HtmlAddress", "HtmlCite", "HtmlCode", "HtmlDefinition", "HtmlKeyboard", "HtmlPreformatted", "HtmlSample", "HtmlTypewriter", "HtmlVariable", "TableNormal", "CommentSubject", "NoList", "OutlineList1", "OutlineList2", "OutlineList3", "TableSimple1", "TableSimple2", "TableSimple3", "TableClassic1", "TableClassic2", "TableClassic3", "TableClassic4", "TableColorful1", "TableColorful2", "TableColorful3", "TableColumns1", "TableColumns2", "TableColumns3", "TableColumns4", "TableColumns5", "TableGrid1", "TableGrid2", "TableGrid3", "TableGrid4", "TableGrid5", "TableGrid6", "TableGrid7", "TableGrid8", "TableList1", "TableList2", "TableList3", "TableList4", "TableList5", "TableList6", "TableList7", "TableList8", "Table3DEffects1", "Table3DEffects2", "Table3DEffects3", "TableContemporary", "TableElegant", "TableProfessional", "TableSubtle1", "TableSubtle2", "TableWeb1", "TableWeb2", "TableWeb3", "BalloonText", "TableGrid", "TableTheme", "PlaceholderText", "NoSpacing", "LightShading", "LightList", "LightGrid", "MediumShading1", "MediumShading2", "MediumList1", "MediumList2", "MediumGrid1", "MediumGrid2", "MediumGrid3", "DarkList", "ColorfulShading", "ColorfulList", "ColorfulGrid", "LightShadingAccent1", "LightListAccent1", "LightGridAccent1", "MediumShading1Accent1", "MediumShading2Accent1", "MediumList1Accent1", "Revision", "ListParagraph", "Quote", "IntenseQuote", "MediumList2Accent1", "MediumGrid1Accent1", "MediumGrid2Accent1", "MediumGrid3Accent1", "DarkListAccent1", "ColorfulShadingAccent1", "ColorfulListAccent1", "ColorfulGridAccent1", "LightShadingAccent2", "LightListAccent2", "LightGridAccent2", "MediumShading1Accent2", "MediumShading2Accent2", "MediumList1Accent2", "MediumList2Accent2", "MediumGrid1Accent2", "MediumGrid2Accent2", "MediumGrid3Accent2", "DarkListAccent2", "ColorfulShadingAccent2", "ColorfulListAccent2", "ColorfulGridAccent2", "LightShadingAccent3", "LightListAccent3", "LightGridAccent3", "MediumShading1Accent3", "MediumShading2Accent3", "MediumList1Accent3", "MediumList2Accent3", "MediumGrid1Accent3", "MediumGrid2Accent3", "MediumGrid3Accent3", "DarkListAccent3", "ColorfulShadingAccent3", "ColorfulListAccent3", "ColorfulGridAccent3", "LightShadingAccent4", "LightListAccent4", "LightGridAccent4", "MediumShading1Accent4", "MediumShading2Accent4", "MediumList1Accent4", "MediumList2Accent4", "MediumGrid1Accent4", "MediumGrid2Accent4", "MediumGrid3Accent4", "DarkListAccent4", "ColorfulShadingAccent4", "ColorfulListAccent4", "ColorfulGridAccent4", "LightShadingAccent5", "LightListAccent5", "LightGridAccent5", "MediumShading1Accent5", "MediumShading2Accent5", "MediumList1Accent5", "MediumList2Accent5", "MediumGrid1Accent5", "MediumGrid2Accent5", "MediumGrid3Accent5", "DarkListAccent5", "ColorfulShadingAccent5", "ColorfulListAccent5", "ColorfulGridAccent5", "LightShadingAccent6", "LightListAccent6", "LightGridAccent6", "MediumShading1Accent6", "MediumShading2Accent6", "MediumList1Accent6", "MediumList2Accent6", "MediumGrid1Accent6", "MediumGrid2Accent6", "MediumGrid3Accent6", "DarkListAccent6", "ColorfulShadingAccent6", "ColorfulListAccent6", "ColorfulGridAccent6", "SubtleEmphasis", "IntenseEmphasis", "SubtleReference", "IntenseReference", "BookTitle", "Bibliography", "TocHeading", "PlainTable1", "PlainTable2", "PlainTable3", "PlainTable4", "PlainTable5", "TableGridLight", "GridTable1Light", "GridTable2", "GridTable3", "GridTable4", "GridTable5Dark", "GridTable6Colorful", "GridTable7Colorful", "GridTable1LightAccent1", "GridTable2Accent1", "GridTable3Accent1", "GridTable4Accent1", "GridTable5DarkAccent1", "GridTable6ColorfulAccent1", "GridTable7ColorfulAccent1", "GridTable1LightAccent2", "GridTable2Accent2", "GridTable3Accent2", "GridTable4Accent2", "GridTable5DarkAccent2", "GridTable6ColorfulAccent2", "GridTable7ColorfulAccent2", "GridTable1LightAccent3", "GridTable2Accent3", "GridTable3Accent3", "GridTable4Accent3", "GridTable5DarkAccent3", "GridTable6ColorfulAccent3", "GridTable7ColorfulAccent3", "GridTable1LightAccent4", "GridTable2Accent4", "GridTable3Accent4", "GridTable4Accent4", "GridTable5DarkAccent4", "GridTable6ColorfulAccent4", "GridTable7ColorfulAccent4", "GridTable1LightAccent5", "GridTable2Accent5", "GridTable3Accent5", "GridTable4Accent5", "GridTable5DarkAccent5", "GridTable6ColorfulAccent5", "GridTable7ColorfulAccent5", "GridTable1LightAccent6", "GridTable2Accent6", "GridTable3Accent6", "GridTable4Accent6", "GridTable5DarkAccent6", "GridTable6ColorfulAccent6", "GridTable7ColorfulAccent6", "ListTable1Light", "ListTable2", "ListTable3", "ListTable4", "ListTable5Dark", "ListTable6Colorful", "ListTable7Colorful", "ListTable1LightAccent1", "ListTable2Accent1", "ListTable3Accent1", "ListTable4Accent1", "ListTable5DarkAccent1", "ListTable6ColorfulAccent1", "ListTable7ColorfulAccent1", "ListTable1LightAccent2", "ListTable2Accent2", "ListTable3Accent2", "ListTable4Accent2", "ListTable5DarkAccent2", "ListTable6ColorfulAccent2", "ListTable7ColorfulAccent2", "ListTable1LightAccent3", "ListTable2Accent3", "ListTable3Accent3", "ListTable4Accent3", "ListTable5DarkAccent3", "ListTable6ColorfulAccent3", "ListTable7ColorfulAccent3", "ListTable1LightAccent4", "ListTable2Accent4", "ListTable3Accent4", "ListTable4Accent4", "ListTable5DarkAccent4", "ListTable6ColorfulAccent4", "ListTable7ColorfulAccent4", "ListTable1LightAccent5", "ListTable2Accent5", "ListTable3Accent5", "ListTable4Accent5", "ListTable5DarkAccent5", "ListTable6ColorfulAccent5", "ListTable7ColorfulAccent5", "ListTable1LightAccent6", "ListTable2Accent6", "ListTable3Accent6", "ListTable4Accent6", "ListTable5DarkAccent6", "ListTable6ColorfulAccent6", "ListTable7ColorfulAccent6", "SmartLink", "Mention", "SmartHyperlink", "Hashtag", "UnresolvedMention", "User", "Nil"]  # noqa: E501
        if not style_identifier.isdigit():
            if style_identifier not in allowed_values:
                raise ValueError(
                    "Invalid value for `style_identifier` ({0}), must be one of {1}"  # noqa: E501
                    .format(style_identifier, allowed_values))
            self._style_identifier = style_identifier
        else:
            self._style_identifier = allowed_values[int(style_identifier) if six.PY3 else long(style_identifier)]

    @property
    def style_name(self):
        """Gets the style_name of this Font.  # noqa: E501

        Gets or sets the name of the character style applied to this formatting.  # noqa: E501

        :return: The style_name of this Font.  # noqa: E501
        :rtype: str
        """
        return self._style_name

    @style_name.setter
    def style_name(self, style_name):
        """Sets the style_name of this Font.

        Gets or sets the name of the character style applied to this formatting.  # noqa: E501

        :param style_name: The style_name of this Font.  # noqa: E501
        :type: str
        """
        self._style_name = style_name

    @property
    def subscript(self):
        """Gets the subscript of this Font.  # noqa: E501

        Gets or sets a value indicating whether the font is formatted as subscript.  # noqa: E501

        :return: The subscript of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._subscript

    @subscript.setter
    def subscript(self, subscript):
        """Sets the subscript of this Font.

        Gets or sets a value indicating whether the font is formatted as subscript.  # noqa: E501

        :param subscript: The subscript of this Font.  # noqa: E501
        :type: bool
        """
        self._subscript = subscript

    @property
    def superscript(self):
        """Gets the superscript of this Font.  # noqa: E501

        Gets or sets a value indicating whether the font is formatted as superscript.  # noqa: E501

        :return: The superscript of this Font.  # noqa: E501
        :rtype: bool
        """
        return self._superscript

    @superscript.setter
    def superscript(self, superscript):
        """Sets the superscript of this Font.

        Gets or sets a value indicating whether the font is formatted as superscript.  # noqa: E501

        :param superscript: The superscript of this Font.  # noqa: E501
        :type: bool
        """
        self._superscript = superscript

    @property
    def text_effect(self):
        """Gets the text_effect of this Font.  # noqa: E501

        Gets or sets the font animation effect.  # noqa: E501

        :return: The text_effect of this Font.  # noqa: E501
        :rtype: str
        """
        return self._text_effect

    @text_effect.setter
    def text_effect(self, text_effect):
        """Sets the text_effect of this Font.

        Gets or sets the font animation effect.  # noqa: E501

        :param text_effect: The text_effect of this Font.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "LasVegasLights", "BlinkingBackground", "SparkleText", "MarchingBlackAnts", "MarchingRedAnts", "Shimmer"]  # noqa: E501
        if not text_effect.isdigit():
            if text_effect not in allowed_values:
                raise ValueError(
                    "Invalid value for `text_effect` ({0}), must be one of {1}"  # noqa: E501
                    .format(text_effect, allowed_values))
            self._text_effect = text_effect
        else:
            self._text_effect = allowed_values[int(text_effect) if six.PY3 else long(text_effect)]

    @property
    def underline(self):
        """Gets the underline of this Font.  # noqa: E501

        Gets or sets the type of underline applied to the font.  # noqa: E501

        :return: The underline of this Font.  # noqa: E501
        :rtype: str
        """
        return self._underline

    @underline.setter
    def underline(self, underline):
        """Sets the underline of this Font.

        Gets or sets the type of underline applied to the font.  # noqa: E501

        :param underline: The underline of this Font.  # noqa: E501
        :type: str
        """
        allowed_values = ["None", "Single", "Words", "Double", "Dotted", "Thick", "Dash", "DotDash", "DotDotDash", "Wavy", "DottedHeavy", "DashHeavy", "DotDashHeavy", "DotDotDashHeavy", "WavyHeavy", "DashLong", "WavyDouble", "DashLongHeavy"]  # noqa: E501
        if not underline.isdigit():
            if underline not in allowed_values:
                raise ValueError(
                    "Invalid value for `underline` ({0}), must be one of {1}"  # noqa: E501
                    .format(underline, allowed_values))
            self._underline = underline
        else:
            self._underline = allowed_values[int(underline) if six.PY3 else long(underline)]

    @property
    def underline_color(self):
        """Gets the underline_color of this Font.  # noqa: E501

        Gets or sets the color of the underline applied to the font.  # noqa: E501

        :return: The underline_color of this Font.  # noqa: E501
        :rtype: XmlColor
        """
        return self._underline_color

    @underline_color.setter
    def underline_color(self, underline_color):
        """Sets the underline_color of this Font.

        Gets or sets the color of the underline applied to the font.  # noqa: E501

        :param underline_color: The underline_color of this Font.  # noqa: E501
        :type: XmlColor
        """
        self._underline_color = underline_color


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Font):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="TestExamples.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import os
import asposewordscloud
import asposewordscloud.models.requests
from asposewordscloud.rest import ApiException
from shutil import copyfile
from test.base_test_context import BaseTestContext

class TestExamples(BaseTestContext):
    def setUp(self):
        super().setUp()
        self.words_api.upload_file(asposewordscloud.models.requests.UploadFileRequest(
            open(os.path.join('ExamplesData', 'test_doc.docx'), 'rb'),
            'test_doc.docx'
        ))


    def test_accept_all_revisions(self):
        documents_dir = os.path.abspath(os.path.realpath(os.path.dirname(__file__)) + "/../ExamplesData")
        words_api = self.words_api
        file_name= 'test_doc.docx'

        # Upload original document to cloud storage.
        my_var1 = open(os.path.join(documents_dir, file_name), 'rb')
        my_var2 = file_name
        upload_file_request = asposewordscloud.models.requests.UploadFileRequest(file_content=my_var1, path=my_var2)
        words_api.upload_file(upload_file_request)

        # Calls AcceptAllRevisions method for document in cloud.
        my_var3 = file_name
        request = asposewordscloud.models.requests.AcceptAllRevisionsRequest(name=my_var3)
        words_api.accept_all_revisions(request)

    def test_accept_all_revisions_online(self):
        documents_dir = os.path.abspath(os.path.realpath(os.path.dirname(__file__)) + "/../ExamplesData")
        words_api = self.words_api
        file_name= 'test_doc.docx'

        # Calls AcceptAllRevisionsOnline method for document in cloud.
        request_document = open(os.path.join(documents_dir, file_name), 'rb')
        request = asposewordscloud.models.requests.AcceptAllRevisionsOnlineRequest(document=request_document)
        accept_all_revisions_online_result = words_api.accept_all_revisions_online(request)
        open('test_result.docx','wb').write(list(accept_all_revisions_online_result.document.values())[0])


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="test_readme.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import os
import re

import asposewordscloud.models.requests
from test.base_test_context import BaseTestContext


class TestReadme(BaseTestContext):

    def test_readme_code(self):
        creds = self.read_config()

        client_secret = creds["ClientSecret"]
        client_id = creds["ClientId"]
        base_url = creds["BaseUrl"]

        local_folder = self.local_common_folder
        filename = "test_multi_pages.docx"

        remote_name = 'TestDeleteDocumentWatermark.docx'
        remote_folder = 'FolderWhereFileLocates'

        # Start README example

        self.words_api = asposewordscloud.WordsApi(client_id, client_secret, base_url)

        upload_request = asposewordscloud.models.requests.UploadFileRequest(
            open(os.path.join(local_folder, filename), 'rb'), os.path.join(remote_folder, remote_name))
        self.words_api.upload_file(upload_request)

        request = asposewordscloud.models.requests.DeleteWatermarkRequest(remote_name, remote_folder)
        self.words_api.delete_watermark(request)

        # End README example

        self.write_to_readme()

    def write_to_readme(self):
        # set regex patterns
        start_pattern = r"^\s*# Start README example\s*$"
        end_pattern = r"^\s*# End README example\s*$"

        # set paths
        source_path = __file__
        readme_path = os.path.dirname(__file__) + "/../README.md"

        # read code from the file
        with open(source_path) as f:
            code_lines = f.readlines()

        # extract readme code
        readme_code = list()
        skip_mode = True
        for line in code_lines:
            if skip_mode:
                skip_mode = (re.match(start_pattern, line) is None)

            if not skip_mode:
                readme_code.append(line)
                skip_mode = not (re.match(end_pattern, line) is None)

        self.assertGreater(len(readme_code), 2)

        # read readme file
        with open(readme_path) as f:
            readme_lines = f.readlines()

        # replace code
        new_readme_lines = list()
        code_mode = False
        for line in readme_lines:
            if not code_mode:
                code_mode = not (re.match(start_pattern, line) is None)

                if code_mode:
                    new_readme_lines.extend(readme_code)

            if code_mode:
                code_mode = re.match(end_pattern, line) is None
                continue

            if not code_mode:
                new_readme_lines.append(line)

        # write to readm
        with open(readme_path, 'w') as f:
            for line in new_readme_lines:
                f.write(line)



# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="list_format_update.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class ListFormatUpdate(object):
    """Paragraph list format element for update.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'list_level_number': 'int',
        'list_id': 'int'
    }

    attribute_map = {
        'list_level_number': 'ListLevelNumber',
        'list_id': 'ListId'
    }

    def __init__(self, list_level_number=None, list_id=None):  # noqa: E501
        """ListFormatUpdate - a model defined in Swagger"""  # noqa: E501

        self._list_level_number = None
        self._list_id = None
        self.discriminator = None

        if list_level_number is not None:
            self.list_level_number = list_level_number
        if list_id is not None:
            self.list_id = list_id

    @property
    def list_level_number(self):
        """Gets the list_level_number of this ListFormatUpdate.  # noqa: E501

        Gets or sets the list level number (0 to 8) for the paragraph. In Word documents, lists may consist of 1 or 9 levels, numbered 0 to 8. Has effect only when the Aspose.Words.ListFormat.List property is set to reference a valid list. Aspose.Words.ListFormat.List.  # noqa: E501

        :return: The list_level_number of this ListFormatUpdate.  # noqa: E501
        :rtype: int
        """
        return self._list_level_number

    @list_level_number.setter
    def list_level_number(self, list_level_number):
        """Sets the list_level_number of this ListFormatUpdate.

        Gets or sets the list level number (0 to 8) for the paragraph. In Word documents, lists may consist of 1 or 9 levels, numbered 0 to 8. Has effect only when the Aspose.Words.ListFormat.List property is set to reference a valid list. Aspose.Words.ListFormat.List.  # noqa: E501

        :param list_level_number: The list_level_number of this ListFormatUpdate.  # noqa: E501
        :type: int
        """
        self._list_level_number = list_level_number

    @property
    def list_id(self):
        """Gets the list_id of this ListFormatUpdate.  # noqa: E501

        Gets or sets the list id of this paragraph. The list that is being assigned to this property must belong to the current document. The list that is being assigned to this property must not be a list style definition.  # noqa: E501

        :return: The list_id of this ListFormatUpdate.  # noqa: E501
        :rtype: int
        """
        return self._list_id

    @list_id.setter
    def list_id(self, list_id):
        """Sets the list_id of this ListFormatUpdate.

        Gets or sets the list id of this paragraph. The list that is being assigned to this property must belong to the current document. The list that is being assigned to this property must not be a list style definition.  # noqa: E501

        :param list_id: The list_id of this ListFormatUpdate.  # noqa: E501
        :type: int
        """
        self._list_id = list_id


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListFormatUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="json_data_load_options.py">
#   Copyright (c) 2023 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import typing_extensions
import datetime
import six
import json

class JsonDataLoadOptions(object):
    """Represents options for parsing JSON data. An instance of this class can be passed into constructors of Aspose.Words.Reporting.JsonDataSource.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'always_generate_root_object': 'bool',
        'exact_date_time_parse_formats': 'list[str]',
        'simple_value_parse_mode': 'str'
    }

    attribute_map = {
        'always_generate_root_object': 'AlwaysGenerateRootObject',
        'exact_date_time_parse_formats': 'ExactDateTimeParseFormats',
        'simple_value_parse_mode': 'SimpleValueParseMode'
    }

    def __init__(self, always_generate_root_object=None, exact_date_time_parse_formats=None, simple_value_parse_mode=None):  # noqa: E501
        """JsonDataLoadOptions - a model defined in Swagger"""  # noqa: E501

        self._always_generate_root_object = None
        self._exact_date_time_parse_formats = None
        self._simple_value_parse_mode = None
        self.discriminator = None

        if always_generate_root_object is not None:
            self.always_generate_root_object = always_generate_root_object
        if exact_date_time_parse_formats is not None:
            self.exact_date_time_parse_formats = exact_date_time_parse_formats
        if simple_value_parse_mode is not None:
            self.simple_value_parse_mode = simple_value_parse_mode

    @property
    def always_generate_root_object(self):
        """Gets the always_generate_root_object of this JsonDataLoadOptions.  # noqa: E501

        Gets or sets a value indicating whether a generated data source will always contain an object for a JSON root element. If a JSON root element contains a single complex property, such an object is not created by default. The default value is false.  # noqa: E501

        :return: The always_generate_root_object of this JsonDataLoadOptions.  # noqa: E501
        :rtype: bool
        """
        return self._always_generate_root_object

    @always_generate_root_object.setter
    def always_generate_root_object(self, always_generate_root_object):
        """Sets the always_generate_root_object of this JsonDataLoadOptions.

        Gets or sets a value indicating whether a generated data source will always contain an object for a JSON root element. If a JSON root element contains a single complex property, such an object is not created by default. The default value is false.  # noqa: E501

        :param always_generate_root_object: The always_generate_root_object of this JsonDataLoadOptions.  # noqa: E501
        :type: bool
        """
        self._always_generate_root_object = always_generate_root_object

    @property
    def exact_date_time_parse_formats(self):
        """Gets the exact_date_time_parse_formats of this JsonDataLoadOptions.  # noqa: E501

        Gets or sets exact formats for parsing JSON date-time values while loading JSON. The default is null. Strings encoded using Microsoft® JSON date-time format (for example, "/Date(1224043200000)/") are always recognized as date-time values regardless of a value of this property. The property defines additional formats to be used while parsing date-time values from strings in the following way: • When Aspose.Words.Reporting.JsonDataLoadOptions.ExactDateTimeParseFormats is null, the ISO-8601 format and all date-time formats supported for the current, English USA, and English New Zealand cultures are used additionally in the mentioned order. • When Aspose.Words.Reporting.JsonDataLoadOptions.ExactDateTimeParseFormats contains strings, they are used as additional date-time formats utilizing the current culture. • When Aspose.Words.Reporting.JsonDataLoadOptions.ExactDateTimeParseFormats is empty, no additional date-time formats are used.  # noqa: E501

        :return: The exact_date_time_parse_formats of this JsonDataLoadOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._exact_date_time_parse_formats

    @exact_date_time_parse_formats.setter
    def exact_date_time_parse_formats(self, exact_date_time_parse_formats):
        """Sets the exact_date_time_parse_formats of this JsonDataLoadOptions.

        Gets or sets exact formats for parsing JSON date-time values while loading JSON. The default is null. Strings encoded using Microsoft® JSON date-time format (for example, "/Date(1224043200000)/") are always recognized as date-time values regardless of a value of this property. The property defines additional formats to be used while parsing date-time values from strings in the following way: • When Aspose.Words.Reporting.JsonDataLoadOptions.ExactDateTimeParseFormats is null, the ISO-8601 format and all date-time formats supported for the current, English USA, and English New Zealand cultures are used additionally in the mentioned order. • When Aspose.Words.Reporting.JsonDataLoadOptions.ExactDateTimeParseFormats contains strings, they are used as additional date-time formats utilizing the current culture. • When Aspose.Words.Reporting.JsonDataLoadOptions.ExactDateTimeParseFormats is empty, no additional date-time formats are used.  # noqa: E501

        :param exact_date_time_parse_formats: The exact_date_time_parse_formats of this JsonDataLoadOptions.  # noqa: E501
        :type: list[str]
        """
        self._exact_date_time_parse_formats = exact_date_time_parse_formats

    @property
    def simple_value_parse_mode(self):
        """Gets the simple_value_parse_mode of this JsonDataLoadOptions.  # noqa: E501

        Gets or sets a mode for parsing JSON simple values (null, boolean, number, integer, and string) while loading JSON. Such a mode does not affect parsing of date-time values. The default is Aspose.Words.Reporting.JsonSimpleValueParseMode.Loose.  # noqa: E501

        :return: The simple_value_parse_mode of this JsonDataLoadOptions.  # noqa: E501
        :rtype: str
        """
        return self._simple_value_parse_mode

    @simple_value_parse_mode.setter
    def simple_value_parse_mode(self, simple_value_parse_mode):
        """Sets the simple_value_parse_mode of this JsonDataLoadOptions.

        Gets or sets a mode for parsing JSON simple values (null, boolean, number, integer, and string) while loading JSON. Such a mode does not affect parsing of date-time values. The default is Aspose.Words.Reporting.JsonSimpleValueParseMode.Loose.  # noqa: E501

        :param simple_value_parse_mode: The simple_value_parse_mode of this JsonDataLoadOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["Loose", "Strict"]  # noqa: E501
        if not simple_value_parse_mode.isdigit():
            if simple_value_parse_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `simple_value_parse_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(simple_value_parse_mode, allowed_values))
            self._simple_value_parse_mode = simple_value_parse_mode
        else:
            self._simple_value_parse_mode = allowed_values[int(simple_value_parse_mode) if six.PY3 else long(simple_value_parse_mode)]


    def extract_files_content(self, filesContentResult):
        """Append the file content result list"""

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return result

    def to_json(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[self.attribute_map[attr]] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[self.attribute_map[attr]] = value.to_dict()
            elif isinstance(value, dict):
                result[self.attribute_map[attr]] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, (datetime.datetime, datetime.date)):
                result[self.attribute_map[attr]] = value.isoformat()
            else:
                result[self.attribute_map[attr]] = value

        return json.dumps(result)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JsonDataLoadOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other